import { Commit } from 'types/Commit'

export const sleepCommitsRelease: Commit[] = [
  {
    hash: 'e059c28',
    committerDate: '2025-03-28T17:08:06+00:00',
    authorDate: '2025-02-25 17:08:06 +0000',
    message: 'Merge pull request #39 from TomPlum/renovate/vite-6.x',
    parents: [
      '0b78e07',
      '867c511'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [],
    isBranchTip: false
  },
  {
    hash: '0b78e07',
    committerDate: '2025-03-26T16:39:50+00:00',
    authorDate: '2025-02-23 16:39:50 +0000',
    message: 'Merge pull request #52 from TomPlum/develop',
    parents: [
      '7355361',
      'efe3dd6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e059c28'
    ],
    isBranchTip: false
  },
  {
    hash: 'efe3dd6',
    committerDate: '2025-03-26T16:38:25+00:00',
    authorDate: '2025-02-23 16:38:25 +0000',
    message: 'feat(chart): moved session highlights card',
    parents: [
      'd524100'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0b78e07'
    ],
    isBranchTip: false
  },
  {
    hash: 'd524100',
    committerDate: '2025-03-26T16:35:33+00:00',
    authorDate: '2025-02-23 16:35:33 +0000',
    message: 'feat(chart): Re-added locale toggle as ascii checkbox',
    parents: [
      '50250a9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'efe3dd6'
    ],
    isBranchTip: false
  },
  {
    hash: '50250a9',
    committerDate: '2025-03-26T16:29:15+00:00',
    authorDate: '2025-02-23 16:29:15 +0000',
    message: 'feat(chart): Added show highlights card toggle to controls + jp translations',
    parents: [
      'bb950c2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd524100'
    ],
    isBranchTip: false
  },
  {
    hash: 'bb950c2',
    committerDate: '2025-03-26T16:08:30+00:00',
    authorDate: '2025-02-23 16:08:30 +0000',
    message: 'feat(chart): Fixed carousel theming in SessionHighlightCard.tsx',
    parents: [
      '432fd9c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '50250a9'
    ],
    isBranchTip: false
  },
  {
    hash: '432fd9c',
    committerDate: '2025-03-26T15:46:54+00:00',
    authorDate: '2025-02-23 15:46:54 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '6115d5f',
      '7355361'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bb950c2'
    ],
    isBranchTip: false
  },
  {
    hash: '6115d5f',
    committerDate: '2025-03-26T13:03:09+00:00',
    authorDate: '2025-02-23 13:03:09 +0000',
    message: 'feat(chart): Extracted HighlightCarouselItem component',
    parents: [
      'b45bf05'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '432fd9c'
    ],
    isBranchTip: false
  },
  {
    hash: 'b45bf05',
    committerDate: '2025-03-26T12:56:22+00:00',
    authorDate: '2025-02-23 12:56:22 +0000',
    message: 'feat(chart): Moved SessionHighlightCard to Highlights module',
    parents: [
      '6beb2d1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6115d5f'
    ],
    isBranchTip: false
  },
  {
    hash: '6beb2d1',
    committerDate: '2025-03-26T12:54:45+00:00',
    authorDate: '2025-02-23 12:54:45 +0000',
    message: 'feat(chart): Extracted NestedProgressCircles components in new Highlights module',
    parents: [
      '2bc6652'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b45bf05'
    ],
    isBranchTip: false
  },
  {
    hash: '2bc6652',
    committerDate: '2025-03-25T23:56:31+00:00',
    authorDate: '2025-02-22 23:56:31 +0000',
    message: 'feat(chart): Added formatDuration util and added details to highlight card',
    parents: [
      'ab51db5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6beb2d1'
    ],
    isBranchTip: false
  },
  {
    hash: 'ab51db5',
    committerDate: '2025-03-25T23:33:27+00:00',
    authorDate: '2025-02-22 23:33:27 +0000',
    message: 'feat(chart): added nested progress circle to session highlight',
    parents: [
      '165b754'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2bc6652'
    ],
    isBranchTip: false
  },
  {
    hash: '165b754',
    committerDate: '2025-03-25T23:24:09+00:00',
    authorDate: '2025-02-22 23:24:09 +0000',
    message: 'feat(chart): starting new session highlight component',
    parents: [
      'eff7491'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ab51db5'
    ],
    isBranchTip: false
  },
  {
    hash: '7355361',
    committerDate: '2025-03-25T22:47:07+00:00',
    authorDate: '2025-02-22 22:47:07 +0000',
    message: 'Merge pull request #51 from TomPlum/develop',
    parents: [
      '515eaa9',
      'eff7491'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0b78e07',
      '432fd9c'
    ],
    isBranchTip: false
  },
  {
    hash: 'eff7491',
    committerDate: '2025-03-25T22:45:59+00:00',
    authorDate: '2025-02-22 22:45:59 +0000',
    message: 'chore(docs): updated web worker loading image for docs',
    parents: [
      '127dd9c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '165b754',
      '7355361'
    ],
    isBranchTip: false
  },
  {
    hash: '127dd9c',
    committerDate: '2025-03-25T22:44:34+00:00',
    authorDate: '2025-02-22 22:44:34 +0000',
    message: 'fix(styling): fixed positioning issue in starry background',
    parents: [
      '0964b7d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eff7491'
    ],
    isBranchTip: false
  },
  {
    hash: '0964b7d',
    committerDate: '2025-03-25T22:33:55+00:00',
    authorDate: '2025-02-22 22:33:55 +0000',
    message: 'fix(params): date range params now default to last 2 months if they are not present on page load',
    parents: [
      'f4ef8e9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '127dd9c'
    ],
    isBranchTip: false
  },
  {
    hash: 'f4ef8e9',
    committerDate: '2025-03-25T22:11:18+00:00',
    authorDate: '2025-02-22 22:11:18 +0000',
    message: 'feat(loading): added starry background to data loading page',
    parents: [
      '5510915'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0964b7d'
    ],
    isBranchTip: false
  },
  {
    hash: '515eaa9',
    committerDate: '2025-03-25T22:05:44+00:00',
    authorDate: '2025-02-22 22:05:44 +0000',
    message: 'Merge pull request #49 from TomPlum/renovate/major-eslint-stylistic-monorepo',
    parents: [
      '88a3ca2',
      '575887a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7355361'
    ],
    isBranchTip: false
  },
  {
    hash: '88a3ca2',
    committerDate: '2025-03-25T22:05:23+00:00',
    authorDate: '2025-02-22 22:05:23 +0000',
    message: 'Merge pull request #48 from TomPlum/renovate/all-minor-patch',
    parents: [
      'fd93615',
      '932be3a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '515eaa9'
    ],
    isBranchTip: false
  },
  {
    hash: 'fd93615',
    committerDate: '2025-03-25T22:05:07+00:00',
    authorDate: '2025-02-22 22:05:07 +0000',
    message: 'Merge pull request #50 from TomPlum/renovate/globals-16.x',
    parents: [
      '3d4d017',
      'f687c53'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '88a3ca2'
    ],
    isBranchTip: false
  },
  {
    hash: '5510915',
    committerDate: '2025-03-25T21:52:51+00:00',
    authorDate: '2025-02-22 21:52:51 +0000',
    message: 'feat(page): added back link on improvements page',
    parents: [
      '202237c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f4ef8e9'
    ],
    isBranchTip: false
  },
  {
    hash: '202237c',
    committerDate: '2025-03-25T21:51:17+00:00',
    authorDate: '2025-02-22 21:51:17 +0000',
    message: 'feat(page): rough first draft of improvements page content',
    parents: [
      '4be118d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5510915'
    ],
    isBranchTip: false
  },
  {
    hash: 'f687c53',
    committerDate: '2025-03-25T07:05:41+00:00',
    authorDate: '2025-02-22 07:05:41 +0000',
    message: 'chore(deps): update dependency globals to v16',
    parents: [
      '3d4d017'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'fd93615'
    ],
    isBranchTip: false
  },
  {
    hash: '575887a',
    committerDate: '2025-03-25T02:47:35+00:00',
    authorDate: '2025-02-22 02:47:35 +0000',
    message: 'chore(deps): update dependency @stylistic/eslint-plugin to v4',
    parents: [
      '3d4d017'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '515eaa9'
    ],
    isBranchTip: false
  },
  {
    hash: '932be3a',
    committerDate: '2025-03-25T02:47:25+00:00',
    authorDate: '2025-02-22 02:47:25 +0000',
    message: 'fix(deps): update all non-major dependencies',
    parents: [
      '3d4d017'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '88a3ca2'
    ],
    isBranchTip: false
  },
  {
    hash: '4be118d',
    committerDate: '2025-03-22T21:06:34+00:00',
    authorDate: '2025-02-19 21:06:34 +0000',
    message: 'chore(docs): added missing ToC entry in readme',
    parents: [
      'a338942'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '202237c'
    ],
    isBranchTip: false
  },
  {
    hash: 'a338942',
    committerDate: '2025-03-19T17:26:41+00:00',
    authorDate: '2025-02-16 17:26:41 +0000',
    message: 'chore(docs): more docs additions in readme',
    parents: [
      'f17afd7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4be118d'
    ],
    isBranchTip: false
  },
  {
    hash: 'f17afd7',
    committerDate: '2025-03-19T17:20:01+00:00',
    authorDate: '2025-02-16 17:20:01 +0000',
    message: 'chore(docs): updated readme images and docs',
    parents: [
      '3d4d017'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a338942'
    ],
    isBranchTip: false
  },
  {
    hash: '3d4d017',
    committerDate: '2025-03-19T15:22:11+00:00',
    authorDate: '2025-02-16 15:22:11 +0000',
    message: 'Merge pull request #47 from TomPlum/renovate/all-minor-patch',
    parents: [
      '5525ed5',
      'f157195'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fd93615',
      'f687c53',
      '575887a',
      '932be3a',
      'f17afd7'
    ],
    isBranchTip: false
  },
  {
    hash: '867c511',
    committerDate: '2025-03-19T15:21:55+00:00',
    authorDate: '2025-02-16 15:21:55 +0000',
    message: 'chore(deps): update dependency vite to v6',
    parents: [
      '5525ed5'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'e059c28'
    ],
    isBranchTip: false
  },
  {
    hash: 'f157195',
    committerDate: '2025-03-19T15:21:05+00:00',
    authorDate: '2025-02-16 15:21:05 +0000',
    message: 'fix(deps): update all non-major dependencies',
    parents: [
      '5525ed5'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '3d4d017'
    ],
    isBranchTip: false
  },
  {
    hash: '5525ed5',
    committerDate: '2025-03-19T15:20:20+00:00',
    authorDate: '2025-02-16 15:20:20 +0000',
    message: 'Merge pull request #38 from TomPlum/develop',
    parents: [
      '5862498',
      '081b2d3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3d4d017',
      '867c511',
      'f157195'
    ],
    isBranchTip: false
  },
  {
    hash: '081b2d3',
    committerDate: '2025-03-19T15:16:44+00:00',
    authorDate: '2025-02-16 15:16:44 +0000',
    message: 'chore(data): added latest pillow data 16/02/2025',
    parents: [
      'a10ab03'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5525ed5'
    ],
    isBranchTip: false
  },
  {
    hash: 'a10ab03',
    committerDate: '2025-03-19T15:02:17+00:00',
    authorDate: '2025-02-16 15:02:17 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '55ec23e',
      '5862498'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '081b2d3'
    ],
    isBranchTip: false
  },
  {
    hash: '5862498',
    committerDate: '2025-03-19T15:00:05+00:00',
    authorDate: '2025-02-16 15:00:05 +0000',
    message: 'Merge pull request #46 from TomPlum/renovate/all-minor-patch',
    parents: [
      '27d7e9e',
      'eeeb1f2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5525ed5',
      'a10ab03'
    ],
    isBranchTip: false
  },
  {
    hash: 'eeeb1f2',
    committerDate: '2025-03-17T01:53:30+00:00',
    authorDate: '2025-02-14 01:53:30 +0000',
    message: 'fix(deps): update all non-major dependencies',
    parents: [
      '27d7e9e'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '5862498'
    ],
    isBranchTip: false
  },
  {
    hash: '55ec23e',
    committerDate: '2025-03-04T15:22:07+00:00',
    authorDate: '2025-02-01 15:22:07 +0000',
    message: 'fix(deps): npm install to fix lockfile issues',
    parents: [
      '75fea53'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a10ab03'
    ],
    isBranchTip: false
  },
  {
    hash: '75fea53',
    committerDate: '2025-03-04T15:21:44+00:00',
    authorDate: '2025-02-01 15:21:44 +0000',
    message: 'Merge branch \'refs/heads/release\' into develop',
    parents: [
      'e11674d',
      '27d7e9e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '55ec23e'
    ],
    isBranchTip: false
  },
  {
    hash: '27d7e9e',
    committerDate: '2025-03-04T15:21:11+00:00',
    authorDate: '2025-02-01 15:21:11 +0000',
    message: 'Merge pull request #45 from TomPlum/renovate/major-eslint-stylistic-monorepo',
    parents: [
      '338b505',
      '0577e9d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5862498',
      'eeeb1f2',
      '75fea53'
    ],
    isBranchTip: false
  },
  {
    hash: '338b505',
    committerDate: '2025-03-04T15:20:55+00:00',
    authorDate: '2025-02-01 15:20:55 +0000',
    message: 'Merge pull request #43 from TomPlum/renovate/jsdom-26.x',
    parents: [
      '988bf8d',
      'ca136bf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '27d7e9e'
    ],
    isBranchTip: false
  },
  {
    hash: '988bf8d',
    committerDate: '2025-03-04T15:20:45+00:00',
    authorDate: '2025-02-01 15:20:45 +0000',
    message: 'Merge pull request #44 from TomPlum/renovate/major-vitest-monorepo',
    parents: [
      'b35728b',
      '648f6e9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '338b505'
    ],
    isBranchTip: false
  },
  {
    hash: 'e11674d',
    committerDate: '2025-03-04T15:17:11+00:00',
    authorDate: '2025-02-01 15:17:11 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '72a5dbb',
      'b35728b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '75fea53'
    ],
    isBranchTip: false
  },
  {
    hash: '0577e9d',
    committerDate: '2025-03-04T15:16:12+00:00',
    authorDate: '2025-02-01 15:16:12 +0000',
    message: 'chore(deps): update dependency @stylistic/eslint-plugin to v3',
    parents: [
      'b35728b'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '27d7e9e'
    ],
    isBranchTip: false
  },
  {
    hash: 'b35728b',
    committerDate: '2025-03-04T15:15:42+00:00',
    authorDate: '2025-02-01 15:15:42 +0000',
    message: 'Merge pull request #42 from TomPlum/renovate/all-minor-patch',
    parents: [
      '09e615d',
      '0f5ae74'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '988bf8d',
      'e11674d',
      '0577e9d'
    ],
    isBranchTip: false
  },
  {
    hash: '0f5ae74',
    committerDate: '2025-03-03T21:51:43+00:00',
    authorDate: '2025-01-31 21:51:43 +0000',
    message: 'fix(deps): update all non-major dependencies',
    parents: [
      '09e615d'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'b35728b'
    ],
    isBranchTip: false
  },
  {
    hash: '648f6e9',
    committerDate: '2025-02-19T09:39:08+00:00',
    authorDate: '2025-01-19 09:39:08 +0000',
    message: 'chore(deps): update vitest monorepo to v3',
    parents: [
      '09e615d'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '988bf8d'
    ],
    isBranchTip: false
  },
  {
    hash: 'ca136bf',
    committerDate: '2025-02-11T01:17:46+00:00',
    authorDate: '2025-01-11 01:17:46 +0000',
    message: 'chore(deps): update dependency jsdom to v26',
    parents: [
      '09e615d'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '338b505'
    ],
    isBranchTip: false
  },
  {
    hash: '09e615d',
    committerDate: '2025-02-09T20:17:13+00:00',
    authorDate: '2025-01-09 20:17:13 +0000',
    message: 'Merge pull request #41 from TomPlum/renovate/react-error-boundary-5.x',
    parents: [
      'b7ec825',
      '2b85a9e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b35728b',
      '0f5ae74',
      '648f6e9',
      'ca136bf'
    ],
    isBranchTip: false
  },
  {
    hash: '72a5dbb',
    committerDate: '2025-02-09T20:16:59+00:00',
    authorDate: '2025-01-09 20:16:59 +0000',
    message: 'fix(deps): removed redundant package-lock.json entries',
    parents: [
      '5281010'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e11674d'
    ],
    isBranchTip: false
  },
  {
    hash: '5281010',
    committerDate: '2025-02-09T20:15:57+00:00',
    authorDate: '2025-01-09 20:15:57 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '000b3aa',
      'b7ec825'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '72a5dbb'
    ],
    isBranchTip: false
  },
  {
    hash: 'b7ec825',
    committerDate: '2025-02-09T20:14:48+00:00',
    authorDate: '2025-01-09 20:14:48 +0000',
    message: 'Merge pull request #35 from TomPlum/renovate/all-minor-patch',
    parents: [
      '810a868',
      '3d680fd'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '09e615d',
      '5281010'
    ],
    isBranchTip: false
  },
  {
    hash: '3d680fd',
    committerDate: '2025-02-08T22:25:06+00:00',
    authorDate: '2025-01-08 22:25:06 +0000',
    message: 'fix(deps): update all non-major dependencies',
    parents: [
      '810a868'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'b7ec825'
    ],
    isBranchTip: false
  },
  {
    hash: '2b85a9e',
    committerDate: '2025-01-21T21:55:38+00:00',
    authorDate: '2024-12-21 21:55:38 +0000',
    message: 'fix(deps): update dependency react-error-boundary to v5',
    parents: [
      '810a868'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '09e615d'
    ],
    isBranchTip: false
  },
  {
    hash: '000b3aa',
    committerDate: '2024-12-29T19:10:41+00:00',
    authorDate: '2024-11-28 19:10:41 +0000',
    message: 'fix(graph): filtered out metric nodes that have a value of 0',
    parents: [
      '45dbbde'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5281010'
    ],
    isBranchTip: false
  },
  {
    hash: '45dbbde',
    committerDate: '2024-12-29T19:08:06+00:00',
    authorDate: '2024-11-28 19:08:06 +0000',
    message: 'feat(graph): minor styling consistency improvements to the ascii inputs',
    parents: [
      '2c60633'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '000b3aa'
    ],
    isBranchTip: false
  },
  {
    hash: '2c60633',
    committerDate: '2024-12-29T18:50:33+00:00',
    authorDate: '2024-11-28 18:50:33 +0000',
    message: 'feat(graph): moved stats ui to bottom right and updated ascii checkbox checked mark',
    parents: [
      '7f60983'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '45dbbde'
    ],
    isBranchTip: false
  },
  {
    hash: '7f60983',
    committerDate: '2024-12-29T18:26:08+00:00',
    authorDate: '2024-11-28 18:26:08 +0000',
    message: 'feat(graph): reduced scene cooldown time to stop node drift and improve performance on first render',
    parents: [
      'cebb57d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2c60633'
    ],
    isBranchTip: false
  },
  {
    hash: 'cebb57d',
    committerDate: '2024-12-29T17:57:17+00:00',
    authorDate: '2024-11-28 17:57:17 +0000',
    message: 'chore(deps): removed react-force-graph and replaced with 3d standalone package and bumped three back to latest',
    parents: [
      '33c38c5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7f60983'
    ],
    isBranchTip: false
  },
  {
    hash: '33c38c5',
    committerDate: '2024-12-29T16:27:32+00:00',
    authorDate: '2024-11-28 16:27:32 +0000',
    message: 'chore(graph): removed redundant import file extensions',
    parents: [
      'f19e207'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'cebb57d'
    ],
    isBranchTip: false
  },
  {
    hash: 'f19e207',
    committerDate: '2024-12-29T16:26:50+00:00',
    authorDate: '2024-11-28 16:26:50 +0000',
    message: 'chore(graph): renamed three scene folder to match module name',
    parents: [
      'b9bc1dc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '33c38c5'
    ],
    isBranchTip: false
  },
  {
    hash: 'b9bc1dc',
    committerDate: '2024-12-29T16:24:07+00:00',
    authorDate: '2024-11-28 16:24:07 +0000',
    message: 'feat(graph): added root node link directional particles and arrows to indicate the passage of time',
    parents: [
      '9c65959'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f19e207'
    ],
    isBranchTip: false
  },
  {
    hash: '9c65959',
    committerDate: '2024-12-29T11:57:08+00:00',
    authorDate: '2024-11-28 11:57:08 +0000',
    message: 'feat(graph): fixed ref typing and reset camera loading state',
    parents: [
      'a172219'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b9bc1dc'
    ],
    isBranchTip: false
  },
  {
    hash: 'a172219',
    committerDate: '2024-12-29T11:37:49+00:00',
    authorDate: '2024-11-28 11:37:49 +0000',
    message: 'feat(graph): renamed and structured three chart component',
    parents: [
      'a3af060'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9c65959'
    ],
    isBranchTip: false
  },
  {
    hash: 'a3af060',
    committerDate: '2024-12-29T11:35:52+00:00',
    authorDate: '2024-11-28 11:35:52 +0000',
    message: 'feat(graph): reworked three scene component structure for better use of context + added ascii button',
    parents: [
      '363c60d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a172219'
    ],
    isBranchTip: false
  },
  {
    hash: '363c60d',
    committerDate: '2024-12-28T17:24:13+00:00',
    authorDate: '2024-11-27 17:24:13 +0000',
    message: 'feat(graph): added draggable nodes button and dynamic node sizes based on percentage',
    parents: [
      'cc0598b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a3af060'
    ],
    isBranchTip: false
  },
  {
    hash: 'cc0598b',
    committerDate: '2024-12-28T16:50:40+00:00',
    authorDate: '2024-11-27 16:50:40 +0000',
    message: 'feat(graph): added new three context and toggle for the scene',
    parents: [
      '6e89c11'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '363c60d'
    ],
    isBranchTip: false
  },
  {
    hash: '6e89c11',
    committerDate: '2024-12-28T16:31:13+00:00',
    authorDate: '2024-11-27 16:31:13 +0000',
    message: 'feat(graph): started adding controls menu for 3d graph',
    parents: [
      '6904884'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'cc0598b'
    ],
    isBranchTip: false
  },
  {
    hash: '6904884',
    committerDate: '2024-12-28T16:30:28+00:00',
    authorDate: '2024-11-27 16:30:28 +0000',
    message: 'feat(graph): minor styling improvements on ascii checkbox and turned checked \'x\' to \'o\'',
    parents: [
      '94b945f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6e89c11'
    ],
    isBranchTip: false
  },
  {
    hash: '94b945f',
    committerDate: '2024-12-28T16:17:49+00:00',
    authorDate: '2024-11-27 16:17:49 +0000',
    message: 'feat(graph): more experimentation with 3d force graph',
    parents: [
      '115846d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6904884'
    ],
    isBranchTip: false
  },
  {
    hash: '115846d',
    committerDate: '2024-12-28T10:35:33+00:00',
    authorDate: '2024-11-27 10:35:33 +0000',
    message: 'feat(graph): added fps and network stats counter to 3d graph',
    parents: [
      '71869c4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '94b945f'
    ],
    isBranchTip: false
  },
  {
    hash: '71869c4',
    committerDate: '2024-12-28T09:10:10+00:00',
    authorDate: '2024-11-27 09:10:10 +0000',
    message: 'fix(config): vite config css preproccessor options now use modern-compiler to fix dart scss warnings',
    parents: [
      'a3476a8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '115846d'
    ],
    isBranchTip: false
  },
  {
    hash: 'a3476a8',
    committerDate: '2024-12-28T09:09:45+00:00',
    authorDate: '2024-11-27 09:09:45 +0000',
    message: 'fix(graph): fixed is3D default query param value and line chart missing opacity keyframes',
    parents: [
      'deba6b5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '71869c4'
    ],
    isBranchTip: false
  },
  {
    hash: 'deba6b5',
    committerDate: '2024-12-27T16:53:18+00:00',
    authorDate: '2024-11-26 16:53:18 +0000',
    message: 'feat(graph): added experimental 3d button and re-instated 3d graph behind it',
    parents: [
      'd8e279c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a3476a8'
    ],
    isBranchTip: false
  },
  {
    hash: '810a868',
    committerDate: '2024-12-27T14:10:47+00:00',
    authorDate: '2024-11-26 14:10:47 +0000',
    message: 'Merge pull request #37 from TomPlum/develop',
    parents: [
      'c31b3a8',
      '3a78717'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b7ec825',
      '3d680fd',
      '2b85a9e'
    ],
    isBranchTip: false
  },
  {
    hash: 'd8e279c',
    committerDate: '2024-12-27T13:46:26+00:00',
    authorDate: '2024-11-26 13:46:26 +0000',
    message: 'chore(graph): removed locale toggle from graph controls ui',
    parents: [
      '3a78717'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'deba6b5'
    ],
    isBranchTip: false
  },
  {
    hash: '3a78717',
    committerDate: '2024-12-27T13:44:29+00:00',
    authorDate: '2024-11-26 13:44:29 +0000',
    message: 'fix(graph): active session info colour gradients now support all new chart view types',
    parents: [
      'd89f085'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '810a868',
      'd8e279c'
    ],
    isBranchTip: false
  },
  {
    hash: 'd89f085',
    committerDate: '2024-12-27T13:43:23+00:00',
    authorDate: '2024-11-26 13:43:23 +0000',
    message: 'chore(graph): renamed stackedMetrics to activeMetrics in chart config context',
    parents: [
      '5f7da3f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3a78717'
    ],
    isBranchTip: false
  },
  {
    hash: '5f7da3f',
    committerDate: '2024-12-27T11:00:51+00:00',
    authorDate: '2024-11-26 11:00:51 +0000',
    message: 'fix(controls): made chart view selector button small to match the other controls',
    parents: [
      '7ca3b25'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd89f085'
    ],
    isBranchTip: false
  },
  {
    hash: '7ca3b25',
    committerDate: '2024-12-27T10:57:41+00:00',
    authorDate: '2024-11-26 10:57:41 +0000',
    message: 'fix(graph): rendered key-less line when in single metric view to stop re-mounting',
    parents: [
      'fc6a3e8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5f7da3f'
    ],
    isBranchTip: false
  },
  {
    hash: 'fc6a3e8',
    committerDate: '2024-12-27T10:35:05+00:00',
    authorDate: '2024-11-26 10:35:05 +0000',
    message: 'fix(graph): chart view selection now correctly updates stacked metrics param',
    parents: [
      'c1b3995'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7ca3b25'
    ],
    isBranchTip: false
  },
  {
    hash: 'c1b3995',
    committerDate: '2024-12-27T10:31:14+00:00',
    authorDate: '2024-11-26 10:31:14 +0000',
    message: 'feat(graph): refactored chart metric selection to support all view types',
    parents: [
      'f61711f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fc6a3e8'
    ],
    isBranchTip: false
  },
  {
    hash: 'f61711f',
    committerDate: '2024-12-27T10:06:44+00:00',
    authorDate: '2024-11-26 10:06:44 +0000',
    message: 'chore(graph): renamed StackedGraphPlaceholder to ChartMetricSelection',
    parents: [
      '62e3f80'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c1b3995'
    ],
    isBranchTip: false
  },
  {
    hash: '62e3f80',
    committerDate: '2024-12-27T10:05:35+00:00',
    authorDate: '2024-11-26 10:05:35 +0000',
    message: 'feat(graph): fixed chart view selector for single metric',
    parents: [
      '17d9d64'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f61711f'
    ],
    isBranchTip: false
  },
  {
    hash: '17d9d64',
    committerDate: '2024-12-27T09:57:09+00:00',
    authorDate: '2024-11-26 09:57:09 +0000',
    message: 'feat(graph): added graph metric selector in multiple metrics view when none are selected',
    parents: [
      'b516162'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '62e3f80'
    ],
    isBranchTip: false
  },
  {
    hash: 'b516162',
    committerDate: '2024-12-26T21:16:17+00:00',
    authorDate: '2024-11-25 21:16:17 +0000',
    message: 'feat(graph): started refactor for adding multiple metric lines on the chart at once',
    parents: [
      '33b5d79'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '17d9d64'
    ],
    isBranchTip: false
  },
  {
    hash: '33b5d79',
    committerDate: '2024-12-26T20:48:51+00:00',
    authorDate: '2024-11-25 20:48:51 +0000',
    message: 'chore(graph): renamed line chart component to be consistent',
    parents: [
      '97b060f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b516162'
    ],
    isBranchTip: false
  },
  {
    hash: '97b060f',
    committerDate: '2024-12-26T19:14:05+00:00',
    authorDate: '2024-11-25 19:14:05 +0000',
    message: 'feat(graph): refactored stacked view toggle into a chart view selector dropdown',
    parents: [
      'e6318eb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '33b5d79'
    ],
    isBranchTip: false
  },
  {
    hash: 'c31b3a8',
    committerDate: '2024-12-26T18:34:13+00:00',
    authorDate: '2024-11-25 18:34:13 +0000',
    message: 'Merge pull request #36 from TomPlum/develop',
    parents: [
      '0b903cc',
      'e6318eb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '810a868'
    ],
    isBranchTip: false
  },
  {
    hash: 'e6318eb',
    committerDate: '2024-12-26T18:31:19+00:00',
    authorDate: '2024-11-25 18:31:19 +0000',
    message: 'test(data): fixed bad file path reference which was breaking a test mock',
    parents: [
      '2d1025f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '97b060f',
      'c31b3a8'
    ],
    isBranchTip: false
  },
  {
    hash: '2d1025f',
    committerDate: '2024-12-26T16:03:20+00:00',
    authorDate: '2024-11-25 16:03:20 +0000',
    message: 'chore(data): added tsdoc and supporting comments to useSleepStageData',
    parents: [
      '1321e4d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e6318eb'
    ],
    isBranchTip: false
  },
  {
    hash: '1321e4d',
    committerDate: '2024-12-26T15:55:53+00:00',
    authorDate: '2024-11-25 15:55:53 +0000',
    message: 'fix(data): filtered sleep stage instance data by their unique IDs to remove duplicates that were breaking the chart',
    parents: [
      '71a1a7e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2d1025f'
    ],
    isBranchTip: false
  },
  {
    hash: '71a1a7e',
    committerDate: '2024-12-26T15:49:06+00:00',
    authorDate: '2024-11-25 15:49:06 +0000',
    message: 'feat(graph): added basic styling to error boundary fallback page',
    parents: [
      '97a941a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1321e4d'
    ],
    isBranchTip: false
  },
  {
    hash: '97a941a',
    committerDate: '2024-12-26T15:48:52+00:00',
    authorDate: '2024-11-25 15:48:52 +0000',
    message: 'feat(graph): reworked metric checkbox styling, no longer uses antd',
    parents: [
      '0d85838'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '71a1a7e'
    ],
    isBranchTip: false
  },
  {
    hash: '0d85838',
    committerDate: '2024-12-26T15:21:04+00:00',
    authorDate: '2024-11-25 15:21:04 +0000',
    message: 'feat(data): added japanese translations for the web worker statuses',
    parents: [
      'cf8e018'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '97a941a'
    ],
    isBranchTip: false
  },
  {
    hash: 'cf8e018',
    committerDate: '2024-12-26T15:17:48+00:00',
    authorDate: '2024-11-25 15:17:48 +0000',
    message: 'feat(graph): added error boundary around application',
    parents: [
      '5e7f6f8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0d85838'
    ],
    isBranchTip: false
  },
  {
    hash: '5e7f6f8',
    committerDate: '2024-12-25T17:38:11+00:00',
    authorDate: '2024-11-24 17:38:11 +0000',
    message: 'feat(graph): added sound toggle to session info',
    parents: [
      '5a0d8f6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'cf8e018'
    ],
    isBranchTip: false
  },
  {
    hash: '5a0d8f6',
    committerDate: '2024-12-25T17:20:40+00:00',
    authorDate: '2024-11-24 17:20:40 +0000',
    message: 'fix(context): inverted context dependencies to fix date selection bug',
    parents: [
      'e42905d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5e7f6f8'
    ],
    isBranchTip: false
  },
  {
    hash: 'e42905d',
    committerDate: '2024-12-25T17:10:58+00:00',
    authorDate: '2024-11-24 17:10:58 +0000',
    message: 'feat(graph): added sleep stage pie chart tooltip',
    parents: [
      '66a83c0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5a0d8f6'
    ],
    isBranchTip: false
  },
  {
    hash: '66a83c0',
    committerDate: '2024-12-25T16:26:24+00:00',
    authorDate: '2024-11-24 16:26:24 +0000',
    message: 'fix(data): added web worker terminate call after done event received',
    parents: [
      '9e9389e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e42905d'
    ],
    isBranchTip: false
  },
  {
    hash: '9e9389e',
    committerDate: '2024-12-25T16:26:03+00:00',
    authorDate: '2024-11-24 16:26:03 +0000',
    message: 'chore(context): split chart config context from sleep context',
    parents: [
      '8e241d2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '66a83c0'
    ],
    isBranchTip: false
  },
  {
    hash: '8e241d2',
    committerDate: '2024-12-25T10:30:47+00:00',
    authorDate: '2024-11-24 10:30:47 +0000',
    message: 'chore(housekeeping): moved sleep context files into its own subdirectory',
    parents: [
      'b7a1cc8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9e9389e'
    ],
    isBranchTip: false
  },
  {
    hash: 'b7a1cc8',
    committerDate: '2024-12-25T10:27:26+00:00',
    authorDate: '2024-11-24 10:27:26 +0000',
    message: 'chore(housekeeping): renamed some components for consistency',
    parents: [
      '0143d04'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8e241d2'
    ],
    isBranchTip: false
  },
  {
    hash: '0143d04',
    committerDate: '2024-12-24T22:48:51+00:00',
    authorDate: '2024-11-23 22:48:51 +0000',
    message: 'fix(housekeeping): fixed bad translations string after folder refactor',
    parents: [
      '25f597f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b7a1cc8'
    ],
    isBranchTip: false
  },
  {
    hash: '25f597f',
    committerDate: '2024-12-24T22:41:41+00:00',
    authorDate: '2024-11-23 22:41:41 +0000',
    message: 'chore(housekeeping): major folder structure and module rework',
    parents: [
      '8e4f92b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0143d04'
    ],
    isBranchTip: false
  },
  {
    hash: '8e4f92b',
    committerDate: '2024-12-24T22:26:38+00:00',
    authorDate: '2024-11-23 22:26:38 +0000',
    message: 'feat(graph): removed active dot from sleep stage areas',
    parents: [
      '47d542c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '25f597f'
    ],
    isBranchTip: false
  },
  {
    hash: '47d542c',
    committerDate: '2024-12-24T22:24:15+00:00',
    authorDate: '2024-11-23 22:24:15 +0000',
    message: 'feat(graph): added stage instance duration to graph tooltip',
    parents: [
      '9248e1f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8e4f92b'
    ],
    isBranchTip: false
  },
  {
    hash: '9248e1f',
    committerDate: '2024-12-24T22:07:08+00:00',
    authorDate: '2024-11-23 22:07:08 +0000',
    message: 'chore(graph): added custom interface for sleep session graph y-axis meta',
    parents: [
      '38190b2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '47d542c'
    ],
    isBranchTip: false
  },
  {
    hash: '38190b2',
    committerDate: '2024-12-24T19:39:33+00:00',
    authorDate: '2024-11-23 19:39:33 +0000',
    message: 'chore(deps): upgraded i18next to major version 24',
    parents: [
      'f8ddbd4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9248e1f'
    ],
    isBranchTip: false
  },
  {
    hash: 'f8ddbd4',
    committerDate: '2024-12-24T19:37:44+00:00',
    authorDate: '2024-11-23 19:37:44 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '4ebf726',
      '0b903cc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '38190b2'
    ],
    isBranchTip: false
  },
  {
    hash: '0b903cc',
    committerDate: '2024-12-24T19:37:29+00:00',
    authorDate: '2024-11-23 19:37:29 +0000',
    message: 'Merge pull request #32 from TomPlum/renovate/all-minor-patch',
    parents: [
      '6e3df33',
      'dc8936d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c31b3a8',
      'f8ddbd4'
    ],
    isBranchTip: false
  },
  {
    hash: '4ebf726',
    committerDate: '2024-12-24T19:35:46+00:00',
    authorDate: '2024-11-23 19:35:46 +0000',
    message: 'feat(graph): added close button to selected session display',
    parents: [
      '9857380'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f8ddbd4'
    ],
    isBranchTip: false
  },
  {
    hash: '9857380',
    committerDate: '2024-12-24T19:30:44+00:00',
    authorDate: '2024-11-23 19:30:44 +0000',
    message: 'chore(graph): improved styling in SleepSessionTooltip.module.scss for labels and values',
    parents: [
      'acd7649'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4ebf726'
    ],
    isBranchTip: false
  },
  {
    hash: 'acd7649',
    committerDate: '2024-12-24T19:29:30+00:00',
    authorDate: '2024-11-23 19:29:30 +0000',
    message: 'chore(graph): extracted SleepSessionBreakdownInfo.tsx component',
    parents: [
      '7723e57'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9857380'
    ],
    isBranchTip: false
  },
  {
    hash: '7723e57',
    committerDate: '2024-12-24T19:24:31+00:00',
    authorDate: '2024-11-23 19:24:31 +0000',
    message: 'feat(graph): sleep stage graph x-ticks are now 30 minute intervals',
    parents: [
      'ff5f173'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'acd7649'
    ],
    isBranchTip: false
  },
  {
    hash: 'ff5f173',
    committerDate: '2024-12-24T19:21:55+00:00',
    authorDate: '2024-11-23 19:21:55 +0000',
    message: 'chore(graph): moved stage transition data to hook and disabled area animations',
    parents: [
      'b754d54'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7723e57'
    ],
    isBranchTip: false
  },
  {
    hash: 'b754d54',
    committerDate: '2024-12-24T19:04:33+00:00',
    authorDate: '2024-11-23 19:04:33 +0000',
    message: 'feat(graph): sleep stage graph tooltip now shows current stage and time',
    parents: [
      'ea79846'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ff5f173'
    ],
    isBranchTip: false
  },
  {
    hash: 'ea79846',
    committerDate: '2024-12-24T15:11:32+00:00',
    authorDate: '2024-11-23 15:11:32 +0000',
    message: 'test(graph): added unit test suite for generateTicks',
    parents: [
      '478a361'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b754d54'
    ],
    isBranchTip: false
  },
  {
    hash: '478a361',
    committerDate: '2024-12-24T15:07:03+00:00',
    authorDate: '2024-11-23 15:07:03 +0000',
    message: 'test(graph): added unit test suite for getSleepStageMetricYValue',
    parents: [
      '9d21764'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ea79846'
    ],
    isBranchTip: false
  },
  {
    hash: '9d21764',
    committerDate: '2024-12-24T15:02:43+00:00',
    authorDate: '2024-11-23 15:02:43 +0000',
    message: 'chore(graph): extracted useSleepStagesAreas hook from breakdown graph',
    parents: [
      'be596e4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '478a361'
    ],
    isBranchTip: false
  },
  {
    hash: 'be596e4',
    committerDate: '2024-12-24T14:25:55+00:00',
    authorDate: '2024-11-23 14:25:55 +0000',
    message: 'feat(graph): sleep stage areas now generate minute granular points along their edges',
    parents: [
      '6ef3091'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9d21764'
    ],
    isBranchTip: false
  },
  {
    hash: 'dc8936d',
    committerDate: '2024-12-24T04:50:20+00:00',
    authorDate: '2024-11-23 04:50:20 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      '6e3df33'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '0b903cc'
    ],
    isBranchTip: false
  },
  {
    hash: '6ef3091',
    committerDate: '2024-12-23T19:56:50+00:00',
    authorDate: '2024-11-22 19:56:50 +0000',
    message: 'feat(graph): refactored sleep stage graph to use real areas instead of reference ones',
    parents: [
      'f60cdc8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'be596e4'
    ],
    isBranchTip: false
  },
  {
    hash: 'f60cdc8',
    committerDate: '2024-12-23T16:46:06+00:00',
    authorDate: '2024-11-22 16:46:06 +0000',
    message: 'feat(graph): extracted useSleepStageData hook from breakdown graph component',
    parents: [
      'b1c9c9b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6ef3091'
    ],
    isBranchTip: false
  },
  {
    hash: '6e3df33',
    committerDate: '2024-12-22T19:54:17+00:00',
    authorDate: '2024-11-21 19:54:17 +0000',
    message: 'Merge pull request #31 from TomPlum/develop',
    parents: [
      'f396ce1',
      'b1c9c9b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0b903cc',
      'dc8936d'
    ],
    isBranchTip: false
  },
  {
    hash: 'b1c9c9b',
    committerDate: '2024-12-22T19:51:52+00:00',
    authorDate: '2024-11-21 19:51:52 +0000',
    message: 'Merge pull request #30 from TomPlum/improve-stage-chart',
    parents: [
      'db3687b',
      'db3c4f9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f60cdc8',
      '6e3df33'
    ],
    isBranchTip: false
  },
  {
    hash: 'db3c4f9',
    committerDate: '2024-12-22T19:50:20+00:00',
    authorDate: '2024-11-21 19:50:20 +0000',
    message: 'feat(graph): improved stage graph x-domain',
    parents: [
      'b4e9d3b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b1c9c9b'
    ],
    isBranchTip: false
  },
  {
    hash: 'b4e9d3b',
    committerDate: '2024-12-22T19:41:09+00:00',
    authorDate: '2024-11-21 19:41:09 +0000',
    message: 'feat(graph): fixed stage breakdown graph y-domain and ticks',
    parents: [
      '5b96a51'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'db3c4f9'
    ],
    isBranchTip: false
  },
  {
    hash: '5b96a51',
    committerDate: '2024-12-22T19:03:51+00:00',
    authorDate: '2024-11-21 19:03:51 +0000',
    message: 'feat(graph): added in reparation code to the sleep stage graph data',
    parents: [
      'd89c2c1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b4e9d3b'
    ],
    isBranchTip: false
  },
  {
    hash: 'd89c2c1',
    committerDate: '2024-12-21T20:58:52+00:00',
    authorDate: '2024-11-20 20:58:52 +0000',
    message: 'feat(graph): corrected stage transition line x-ordinates',
    parents: [
      'ced9837'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5b96a51'
    ],
    isBranchTip: false
  },
  {
    hash: 'ced9837',
    committerDate: '2024-12-21T18:45:26+00:00',
    authorDate: '2024-11-20 18:45:26 +0000',
    message: 'feat(graph): switched sleep stage scatter to reference areas',
    parents: [
      '9b4a1b5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd89c2c1'
    ],
    isBranchTip: false
  },
  {
    hash: '9b4a1b5',
    committerDate: '2024-12-21T14:59:16+00:00',
    authorDate: '2024-11-20 14:59:16 +0000',
    message: 'feat(graph): fixed breakdown graph stage connecting lines',
    parents: [
      '1d21e76'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ced9837'
    ],
    isBranchTip: false
  },
  {
    hash: '1d21e76',
    committerDate: '2024-12-21T14:44:03+00:00',
    authorDate: '2024-11-20 14:44:03 +0000',
    message: 'feat(graph): fixed sorting of stage data in breakdown graph',
    parents: [
      '76eb4f3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9b4a1b5'
    ],
    isBranchTip: false
  },
  {
    hash: '76eb4f3',
    committerDate: '2024-12-20T20:53:45+00:00',
    authorDate: '2024-11-19 20:53:45 +0000',
    message: 'feat(graph): starting refactoring breakdown chart',
    parents: [
      'db3687b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1d21e76'
    ],
    isBranchTip: false
  },
  {
    hash: 'db3687b',
    committerDate: '2024-12-20T17:16:54+00:00',
    authorDate: '2024-11-19 17:16:54 +0000',
    message: 'feat(graph): line chart x-axis tick now changes format for small ranges',
    parents: [
      'a18a5c4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b1c9c9b',
      '76eb4f3'
    ],
    isBranchTip: false
  },
  {
    hash: 'a18a5c4',
    committerDate: '2024-12-20T17:09:14+00:00',
    authorDate: '2024-11-19 17:09:14 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      'de17621',
      'f396ce1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'db3687b'
    ],
    isBranchTip: false
  },
  {
    hash: 'f396ce1',
    committerDate: '2024-12-20T17:08:58+00:00',
    authorDate: '2024-11-19 17:08:58 +0000',
    message: 'Merge pull request #26 from TomPlum/renovate/all-minor-patch',
    parents: [
      '8eda2d7',
      '5752a89'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6e3df33',
      'a18a5c4'
    ],
    isBranchTip: false
  },
  {
    hash: 'de17621',
    committerDate: '2024-12-20T17:08:30+00:00',
    authorDate: '2024-11-19 17:08:30 +0000',
    message: 'test(data): fixed failing test for useLinearRegression.spec.ts',
    parents: [
      'b0f2ce3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a18a5c4'
    ],
    isBranchTip: false
  },
  {
    hash: '5752a89',
    committerDate: '2024-12-20T14:00:17+00:00',
    authorDate: '2024-11-19 14:00:17 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      '8eda2d7'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'f396ce1'
    ],
    isBranchTip: false
  },
  {
    hash: 'b0f2ce3',
    committerDate: '2024-12-19T17:35:25+00:00',
    authorDate: '2024-11-18 17:35:25 +0000',
    message: 'feat(graph): added custom sleep stage tooltip and extracted display name util',
    parents: [
      'dad2e46'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'de17621'
    ],
    isBranchTip: false
  },
  {
    hash: 'dad2e46',
    committerDate: '2024-12-19T17:06:00+00:00',
    authorDate: '2024-11-18 17:06:00 +0000',
    message: 'chore(data): updated docs regarding Apples Cocoa Datetime API',
    parents: [
      '3c495cc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b0f2ce3'
    ],
    isBranchTip: false
  },
  {
    hash: '3c495cc',
    committerDate: '2024-12-18T19:12:19+00:00',
    authorDate: '2024-11-17 19:12:19 +0000',
    message: 'feat(graph): extracted legend item component and updated styles',
    parents: [
      '7d91ff0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'dad2e46'
    ],
    isBranchTip: false
  },
  {
    hash: '7d91ff0',
    committerDate: '2024-12-18T19:05:12+00:00',
    authorDate: '2024-11-17 19:05:12 +0000',
    message: 'feat(graph): added duration in sleep session info',
    parents: [
      '4be777a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3c495cc'
    ],
    isBranchTip: false
  },
  {
    hash: '4be777a',
    committerDate: '2024-12-18T18:22:47+00:00',
    authorDate: '2024-11-17 18:22:47 +0000',
    message: 'feat(graph): added endTime to graph data and mapped date range to session info',
    parents: [
      '0cf76da'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7d91ff0'
    ],
    isBranchTip: false
  },
  {
    hash: '0cf76da',
    committerDate: '2024-12-18T18:06:42+00:00',
    authorDate: '2024-11-17 18:06:42 +0000',
    message: 'chore(graph): refactored selected session state management (hoisted to context)',
    parents: [
      '954670c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4be777a'
    ],
    isBranchTip: false
  },
  {
    hash: '8eda2d7',
    committerDate: '2024-12-18T17:33:07+00:00',
    authorDate: '2024-11-17 17:33:07 +0000',
    message: 'Merge pull request #29 from TomPlum/develop',
    parents: [
      '64ae166',
      '954670c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f396ce1',
      '5752a89'
    ],
    isBranchTip: false
  },
  {
    hash: '954670c',
    committerDate: '2024-12-18T17:30:54+00:00',
    authorDate: '2024-11-17 17:30:54 +0000',
    message: 'fix(ci): made dates in useLinearRegression.spec.ts UTC for CI',
    parents: [
      '419257d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0cf76da',
      '8eda2d7'
    ],
    isBranchTip: false
  },
  {
    hash: '419257d',
    committerDate: '2024-12-18T17:26:00+00:00',
    authorDate: '2024-11-17 17:26:00 +0000',
    message: 'debug(ci): added date check in develop workflow to check TZ',
    parents: [
      '52dfc3f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '954670c'
    ],
    isBranchTip: false
  },
  {
    hash: '52dfc3f',
    committerDate: '2024-12-18T17:20:05+00:00',
    authorDate: '2024-11-17 17:20:05 +0000',
    message: 'test(data): used dayjs utc in useLinearRegression to try and fix ci tests',
    parents: [
      'e7a2380'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '419257d'
    ],
    isBranchTip: false
  },
  {
    hash: 'e7a2380',
    committerDate: '2024-12-18T17:19:28+00:00',
    authorDate: '2024-11-17 17:19:28 +0000',
    message: 'feat(graph): extracted useGraphHeight hook and used in placeholder component too',
    parents: [
      'd31697d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '52dfc3f'
    ],
    isBranchTip: false
  },
  {
    hash: 'd31697d',
    committerDate: '2024-12-18T17:11:47+00:00',
    authorDate: '2024-11-17 17:11:47 +0000',
    message: 'fix(graph): tweaked line chart graph height when in stacked view with a selected session',
    parents: [
      '8a68890'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e7a2380'
    ],
    isBranchTip: false
  },
  {
    hash: '8a68890',
    committerDate: '2024-12-18T16:58:58+00:00',
    authorDate: '2024-11-17 16:58:58 +0000',
    message: 'feat(ci): set UTC timezone in develop workflow',
    parents: [
      'df5f451'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd31697d'
    ],
    isBranchTip: false
  },
  {
    hash: 'df5f451',
    committerDate: '2024-12-18T16:57:27+00:00',
    authorDate: '2024-11-17 16:57:27 +0000',
    message: 'feat(ci): added new develop workflow for building/testing on PRs',
    parents: [
      '7308bc3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8a68890'
    ],
    isBranchTip: false
  },
  {
    hash: '7308bc3',
    committerDate: '2024-12-18T16:53:28+00:00',
    authorDate: '2024-11-17 16:53:28 +0000',
    message: 'fix(ci): added UTC timezone to release workflow config',
    parents: [
      '310412c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'df5f451'
    ],
    isBranchTip: false
  },
  {
    hash: '64ae166',
    committerDate: '2024-12-18T16:48:29+00:00',
    authorDate: '2024-11-17 16:48:29 +0000',
    message: 'Merge pull request #28 from TomPlum/develop',
    parents: [
      'c6a41eb',
      '310412c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8eda2d7'
    ],
    isBranchTip: false
  },
  {
    hash: '310412c',
    committerDate: '2024-12-18T16:48:01+00:00',
    authorDate: '2024-11-17 16:48:01 +0000',
    message: 'feat(ci): added unit tests to release workflow',
    parents: [
      '0f637b2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7308bc3',
      '64ae166'
    ],
    isBranchTip: false
  },
  {
    hash: '0f637b2',
    committerDate: '2024-12-18T16:47:10+00:00',
    authorDate: '2024-11-17 16:47:10 +0000',
    message: 'test(data): fixed failing tests and added test:ci script',
    parents: [
      '6aa8dab'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '310412c'
    ],
    isBranchTip: false
  },
  {
    hash: '6aa8dab',
    committerDate: '2024-12-18T16:44:09+00:00',
    authorDate: '2024-11-17 16:44:09 +0000',
    message: 'fix(data): moved env util into sub-dir to fix build issue',
    parents: [
      '0237445'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0f637b2'
    ],
    isBranchTip: false
  },
  {
    hash: 'c6a41eb',
    committerDate: '2024-12-18T15:25:29+00:00',
    authorDate: '2024-11-17 15:25:29 +0000',
    message: 'Merge pull request #27 from TomPlum/develop',
    parents: [
      'd52b826',
      '0237445'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '64ae166'
    ],
    isBranchTip: false
  },
  {
    hash: '0237445',
    committerDate: '2024-12-18T15:06:15+00:00',
    authorDate: '2024-11-17 15:06:15 +0000',
    message: 'feat(graph): duration breakdown pie chart now matches other charts animation timings',
    parents: [
      '33e8dd5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6aa8dab',
      'c6a41eb'
    ],
    isBranchTip: false
  },
  {
    hash: '33e8dd5',
    committerDate: '2024-12-18T15:04:26+00:00',
    authorDate: '2024-11-17 15:04:26 +0000',
    message: 'feat(graph): pushed down session selection code to prevent re-renders',
    parents: [
      '072d7d6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0237445'
    ],
    isBranchTip: false
  },
  {
    hash: '072d7d6',
    committerDate: '2024-12-18T14:53:23+00:00',
    authorDate: '2024-11-17 14:53:23 +0000',
    message: 'feat(graph): added legend to sleep stage breakdown graph',
    parents: [
      '947600b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '33e8dd5'
    ],
    isBranchTip: false
  },
  {
    hash: '947600b',
    committerDate: '2024-12-18T14:38:15+00:00',
    authorDate: '2024-11-17 14:38:15 +0000',
    message: 'feat(graph): sleep stage chart is now size aware and resizes bars appropriately',
    parents: [
      '5861283'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '072d7d6'
    ],
    isBranchTip: false
  },
  {
    hash: '5861283',
    committerDate: '2024-12-18T14:32:24+00:00',
    authorDate: '2024-11-17 14:32:24 +0000',
    message: 'feat(graph): removed pie chart from chart tooltip',
    parents: [
      'e778c0d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '947600b'
    ],
    isBranchTip: false
  },
  {
    hash: 'e778c0d',
    committerDate: '2024-12-18T14:25:18+00:00',
    authorDate: '2024-11-17 14:25:18 +0000',
    message: 'feat(graph): added duration breakdown pie chart to selected session info',
    parents: [
      '6c21df1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5861283'
    ],
    isBranchTip: false
  },
  {
    hash: '6c21df1',
    committerDate: '2024-12-18T14:22:01+00:00',
    authorDate: '2024-11-17 14:22:01 +0000',
    message: 'feat(graph): added selected session into query parameters',
    parents: [
      '5beb80b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e778c0d'
    ],
    isBranchTip: false
  },
  {
    hash: '5beb80b',
    committerDate: '2024-12-18T13:53:07+00:00',
    authorDate: '2024-11-17 13:53:07 +0000',
    message: 'chore(lint): added quote-props eslint rule and ran --fix',
    parents: [
      'e82dd75'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6c21df1'
    ],
    isBranchTip: false
  },
  {
    hash: 'e82dd75',
    committerDate: '2024-12-18T13:52:28+00:00',
    authorDate: '2024-11-17 13:52:28 +0000',
    message: 'test(data): added test suite for scanTables utility',
    parents: [
      'f6e0c4e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5beb80b'
    ],
    isBranchTip: false
  },
  {
    hash: 'f6e0c4e',
    committerDate: '2024-12-18T13:27:51+00:00',
    authorDate: '2024-11-17 13:27:51 +0000',
    message: 'fix(data): added missing benchmark start() call to scanTables',
    parents: [
      'a09f9ad'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e82dd75'
    ],
    isBranchTip: false
  },
  {
    hash: 'a09f9ad',
    committerDate: '2024-12-18T13:26:16+00:00',
    authorDate: '2024-11-17 13:26:16 +0000',
    message: 'test(data): updated unknown time delta message and added tests for it',
    parents: [
      'ac05a9f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f6e0c4e'
    ],
    isBranchTip: false
  },
  {
    hash: 'ac05a9f',
    committerDate: '2024-12-18T13:18:00+00:00',
    authorDate: '2024-11-17 13:18:00 +0000',
    message: 'test(data): added parseDataLine utility tests',
    parents: [
      '74f829c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a09f9ad'
    ],
    isBranchTip: false
  },
  {
    hash: '74f829c',
    committerDate: '2024-12-18T12:57:06+00:00',
    authorDate: '2024-11-17 12:57:06 +0000',
    message: 'test(data): added readRawDatabaseExport tests',
    parents: [
      'ddd3298'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ac05a9f'
    ],
    isBranchTip: false
  },
  {
    hash: 'ddd3298',
    committerDate: '2024-12-18T12:45:42+00:00',
    authorDate: '2024-11-17 12:45:42 +0000',
    message: 'test(data): added readFile unit tests and env utility class',
    parents: [
      'ca95d1b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '74f829c'
    ],
    isBranchTip: false
  },
  {
    hash: 'ca95d1b',
    committerDate: '2024-12-17T18:40:13+00:00',
    authorDate: '2024-11-16 18:40:13 +0000',
    message: 'feat(graph): added sound reference lines to stage breakdown graph',
    parents: [
      '87c3e4b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ddd3298'
    ],
    isBranchTip: false
  },
  {
    hash: '87c3e4b',
    committerDate: '2024-12-16T19:04:17+00:00',
    authorDate: '2024-11-15 19:04:17 +0000',
    message: 'feat(graph): passed sleep sound data into session info component from context',
    parents: [
      '43767e6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ca95d1b'
    ],
    isBranchTip: false
  },
  {
    hash: '43767e6',
    committerDate: '2024-12-16T17:02:12+00:00',
    authorDate: '2024-11-15 17:02:12 +0000',
    message: 'feat(data): worker file reader now calculates uncompressed file size',
    parents: [
      'eb5e0ad'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '87c3e4b'
    ],
    isBranchTip: false
  },
  {
    hash: 'eb5e0ad',
    committerDate: '2024-12-16T17:01:52+00:00',
    authorDate: '2024-11-15 17:01:52 +0000',
    message: 'test(data): added unit tests and docs for sendMessage.ts',
    parents: [
      'dc56de6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '43767e6'
    ],
    isBranchTip: false
  },
  {
    hash: 'dc56de6',
    committerDate: '2024-12-16T16:54:15+00:00',
    authorDate: '2024-11-15 16:54:15 +0000',
    message: 'test(data): added unit tests and docs for formatNumber.ts',
    parents: [
      'a9d6cf6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eb5e0ad'
    ],
    isBranchTip: false
  },
  {
    hash: 'a9d6cf6',
    committerDate: '2024-12-16T16:52:09+00:00',
    authorDate: '2024-11-15 16:52:09 +0000',
    message: 'test(data): added unit test for convertTimestamp.ts',
    parents: [
      '9cdfa40'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'dc56de6'
    ],
    isBranchTip: false
  },
  {
    hash: '9cdfa40',
    committerDate: '2024-12-16T16:44:36+00:00',
    authorDate: '2024-11-15 16:44:36 +0000',
    message: 'fix(data): fixed benchmark delta bug and added unit tests',
    parents: [
      '724f9ef'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a9d6cf6'
    ],
    isBranchTip: false
  },
  {
    hash: '724f9ef',
    committerDate: '2024-12-15T21:55:11+00:00',
    authorDate: '2024-11-14 21:55:11 +0000',
    message: 'chore(data): added benchmark util to encapsulate timing and delta formatting',
    parents: [
      '8472bb5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9cdfa40'
    ],
    isBranchTip: false
  },
  {
    hash: '8472bb5',
    committerDate: '2024-12-15T21:45:41+00:00',
    authorDate: '2024-11-14 21:45:41 +0000',
    message: 'test(data): added unit test suite for convertSleepStage.ts',
    parents: [
      'd52b826'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '724f9ef'
    ],
    isBranchTip: false
  },
  {
    hash: 'd52b826',
    committerDate: '2024-12-15T21:38:52+00:00',
    authorDate: '2024-11-14 21:38:52 +0000',
    message: 'Merge pull request #24 from TomPlum/renovate/all-minor-patch',
    parents: [
      '744a388',
      '328c273'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c6a41eb',
      '8472bb5'
    ],
    isBranchTip: false
  },
  {
    hash: '744a388',
    committerDate: '2024-12-15T21:38:02+00:00',
    authorDate: '2024-11-14 21:38:02 +0000',
    message: 'Merge pull request #25 from TomPlum/feature/parse-raw-data',
    parents: [
      '2888162',
      '4c98b03'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd52b826'
    ],
    isBranchTip: false
  },
  {
    hash: '4c98b03',
    committerDate: '2024-12-15T19:22:19+00:00',
    authorDate: '2024-11-14 19:22:19 +0000',
    message: 'chore(data): moved worker type and shortened imports',
    parents: [
      '9b96063'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '744a388'
    ],
    isBranchTip: false
  },
  {
    hash: '9b96063',
    committerDate: '2024-12-15T19:17:58+00:00',
    authorDate: '2024-11-14 19:17:58 +0000',
    message: 'chore(data): reduced more redundant code for file reading',
    parents: [
      'c675f33'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4c98b03'
    ],
    isBranchTip: false
  },
  {
    hash: 'c675f33',
    committerDate: '2024-12-15T19:11:32+00:00',
    authorDate: '2024-11-14 19:11:32 +0000',
    message: 'chore(data): extracted session validation function to reduce redundant code',
    parents: [
      'ebec2f8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9b96063'
    ],
    isBranchTip: false
  },
  {
    hash: 'ebec2f8',
    committerDate: '2024-12-15T19:07:04+00:00',
    authorDate: '2024-11-14 19:07:04 +0000',
    message: 'test(data): installed @vitest/web-worker to fix failing tests',
    parents: [
      'b3a7721'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c675f33'
    ],
    isBranchTip: false
  },
  {
    hash: 'b3a7721',
    committerDate: '2024-12-15T16:18:11+00:00',
    authorDate: '2024-11-14 16:18:11 +0000',
    message: 'chore(config): added --host flag to dev script so the server is available on the LAN',
    parents: [
      'f6a4794'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ebec2f8'
    ],
    isBranchTip: false
  },
  {
    hash: '328c273',
    committerDate: '2024-12-15T13:09:47+00:00',
    authorDate: '2024-11-14 13:09:47 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      '2888162'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'd52b826'
    ],
    isBranchTip: false
  },
  {
    hash: 'f6a4794',
    committerDate: '2024-12-15T12:10:51+00:00',
    authorDate: '2024-11-14 12:10:51 +0000',
    message: 'chore(data): started extracting data worker into its own module of files',
    parents: [
      '2c6a2a7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b3a7721'
    ],
    isBranchTip: false
  },
  {
    hash: '2c6a2a7',
    committerDate: '2024-12-14T20:45:31+00:00',
    authorDate: '2024-11-13 20:45:31 +0000',
    message: 'feat(graph): updated active session file name and moved types from worker to types file',
    parents: [
      '0261ff8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f6a4794'
    ],
    isBranchTip: false
  },
  {
    hash: '0261ff8',
    committerDate: '2024-12-14T18:01:15+00:00',
    authorDate: '2024-11-13 18:01:15 +0000',
    message: 'feat(graph): changed breakdown chart y value type and added tooltip',
    parents: [
      '0d66a55'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2c6a2a7'
    ],
    isBranchTip: false
  },
  {
    hash: '0d66a55',
    committerDate: '2024-12-14T16:24:04+00:00',
    authorDate: '2024-11-13 16:24:04 +0000',
    message: 'chore(data): renamed statusCode -> code and added extra docs to worker types',
    parents: [
      '1bb1a3f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0261ff8'
    ],
    isBranchTip: false
  },
  {
    hash: '1bb1a3f',
    committerDate: '2024-12-14T16:20:58+00:00',
    authorDate: '2024-11-13 16:20:58 +0000',
    message: 'feat(data): extracted and simplified worker number formatter',
    parents: [
      '181a606'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0d66a55'
    ],
    isBranchTip: false
  },
  {
    hash: '181a606',
    committerDate: '2024-12-14T16:14:39+00:00',
    authorDate: '2024-11-13 16:14:39 +0000',
    message: 'feat(data): added timeouts to throttle worker messages (callback hell, oops)',
    parents: [
      '34e6895'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1bb1a3f'
    ],
    isBranchTip: false
  },
  {
    hash: '34e6895',
    committerDate: '2024-12-14T16:05:57+00:00',
    authorDate: '2024-11-13 16:05:57 +0000',
    message: 'feat(data): tweaks to web worker messaging',
    parents: [
      '05b851a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '181a606'
    ],
    isBranchTip: false
  },
  {
    hash: '05b851a',
    committerDate: '2024-12-14T09:04:42+00:00',
    authorDate: '2024-11-13 09:04:42 +0000',
    message: 'feat(data): added extra worker events for preprocessing stages',
    parents: [
      '053033d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '34e6895'
    ],
    isBranchTip: false
  },
  {
    hash: '053033d',
    committerDate: '2024-12-13T18:57:10+00:00',
    authorDate: '2024-11-12 18:57:10 +0000',
    message: 'fix(data): significantly improved worker performance (35s -> 50ms)',
    parents: [
      '94c5cdb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '05b851a'
    ],
    isBranchTip: false
  },
  {
    hash: '94c5cdb',
    committerDate: '2024-12-13T18:37:10+00:00',
    authorDate: '2024-11-12 18:37:10 +0000',
    message: 'feat(graph): selection session info/graph now renders in stacked view',
    parents: [
      'f05bba9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '053033d'
    ],
    isBranchTip: false
  },
  {
    hash: 'f05bba9',
    committerDate: '2024-12-13T18:32:17+00:00',
    authorDate: '2024-11-12 18:32:17 +0000',
    message: 'feat(data): added slight delay to final worker event to show data parsing message',
    parents: [
      '00d2522'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '94c5cdb'
    ],
    isBranchTip: false
  },
  {
    hash: '00d2522',
    committerDate: '2024-12-13T18:24:05+00:00',
    authorDate: '2024-11-12 18:24:05 +0000',
    message: 'chore(data): cleared 2 x TODOs in web worker',
    parents: [
      'be23a35'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f05bba9'
    ],
    isBranchTip: false
  },
  {
    hash: 'be23a35',
    committerDate: '2024-12-13T17:39:10+00:00',
    authorDate: '2024-11-12 17:39:10 +0000',
    message: 'feat(graph): added breathing radial gradient to loading component',
    parents: [
      'e55624f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '00d2522'
    ],
    isBranchTip: false
  },
  {
    hash: 'e55624f',
    committerDate: '2024-12-13T17:29:04+00:00',
    authorDate: '2024-11-12 17:29:04 +0000',
    message: 'chore(graph): extracted useDynamicFavicon hook',
    parents: [
      '300166e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'be23a35'
    ],
    isBranchTip: false
  },
  {
    hash: '300166e',
    committerDate: '2024-12-13T17:27:23+00:00',
    authorDate: '2024-11-12 17:27:23 +0000',
    message: 'chore(graph): extracted SleepStageBar component',
    parents: [
      'ebc5a24'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e55624f'
    ],
    isBranchTip: false
  },
  {
    hash: 'ebc5a24',
    committerDate: '2024-12-13T17:19:29+00:00',
    authorDate: '2024-11-12 17:19:29 +0000',
    message: 'chore(data): removed old CSV data hook from context provider',
    parents: [
      '4a265bf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '300166e'
    ],
    isBranchTip: false
  },
  {
    hash: '4a265bf',
    committerDate: '2024-12-13T17:17:11+00:00',
    authorDate: '2024-11-12 17:17:11 +0000',
    message: 'feat(graph): started adding info box to breakdown graph',
    parents: [
      '77aec21'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ebc5a24'
    ],
    isBranchTip: false
  },
  {
    hash: '77aec21',
    committerDate: '2024-12-13T17:01:01+00:00',
    authorDate: '2024-11-12 17:01:01 +0000',
    message: 'fix(graph): fixed yTicks in SleepSessionStageBreakdownGraph',
    parents: [
      'f3ad7d7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4a265bf'
    ],
    isBranchTip: false
  },
  {
    hash: 'f3ad7d7',
    committerDate: '2024-12-13T16:56:09+00:00',
    authorDate: '2024-11-12 16:56:09 +0000',
    message: 'feat(graph): fixed raw stage mapping and session -> stages ID mapping',
    parents: [
      '52e1dd5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '77aec21'
    ],
    isBranchTip: false
  },
  {
    hash: '52e1dd5',
    committerDate: '2024-12-13T15:54:03+00:00',
    authorDate: '2024-11-12 15:54:03 +0000',
    message: 'feat(data): data worker typing improvements + TODOs',
    parents: [
      '8ab78a0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f3ad7d7'
    ],
    isBranchTip: false
  },
  {
    hash: '8ab78a0',
    committerDate: '2024-12-13T14:44:30+00:00',
    authorDate: '2024-11-12 14:44:30 +0000',
    message: 'feat(graph): moved sleep stage graph to the bottom and fixed heights',
    parents: [
      '8af99c6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '52e1dd5'
    ],
    isBranchTip: false
  },
  {
    hash: '8af99c6',
    committerDate: '2024-12-13T14:13:45+00:00',
    authorDate: '2024-11-12 14:13:45 +0000',
    message: 'feat(graph): added custom line active dot to bind click events to sleep breakdown',
    parents: [
      '9bc2a52'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8ab78a0'
    ],
    isBranchTip: false
  },
  {
    hash: '9bc2a52',
    committerDate: '2024-12-13T08:28:13+00:00',
    authorDate: '2024-11-12 08:28:13 +0000',
    message: 'feat(data): minor copy and styling improvements to worker events and loading page',
    parents: [
      'd5271f3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8af99c6'
    ],
    isBranchTip: false
  },
  {
    hash: 'd5271f3',
    committerDate: '2024-12-12T21:13:25+00:00',
    authorDate: '2024-11-11 21:13:25 +0000',
    message: 'feat(data): added timings and payload data for other worker events',
    parents: [
      'eda7bbf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9bc2a52'
    ],
    isBranchTip: false
  },
  {
    hash: 'eda7bbf',
    committerDate: '2024-12-12T20:58:36+00:00',
    authorDate: '2024-11-11 20:58:36 +0000',
    message: 'feat(data): added custom payload to worker messages and sent file size',
    parents: [
      '0dfc9ec'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd5271f3'
    ],
    isBranchTip: false
  },
  {
    hash: '0dfc9ec',
    committerDate: '2024-12-12T20:33:18+00:00',
    authorDate: '2024-11-11 20:33:18 +0000',
    message: 'feat(data): fixed some of the failing data web worker event messages',
    parents: [
      '8580cc5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eda7bbf'
    ],
    isBranchTip: false
  },
  {
    hash: '8580cc5',
    committerDate: '2024-12-12T20:21:46+00:00',
    authorDate: '2024-11-11 20:21:46 +0000',
    message: 'feat(data): refactored worker to use Worker constructor to support type imports',
    parents: [
      '73fbcc4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0dfc9ec'
    ],
    isBranchTip: false
  },
  {
    hash: '73fbcc4',
    committerDate: '2024-12-12T16:32:43+00:00',
    authorDate: '2024-11-11 16:32:43 +0000',
    message: 'feat(data): added percentage to data worker message events for granular tracking',
    parents: [
      'dab5c7b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8580cc5'
    ],
    isBranchTip: false
  },
  {
    hash: 'dab5c7b',
    committerDate: '2024-12-12T15:56:24+00:00',
    authorDate: '2024-11-11 15:56:24 +0000',
    message: 'feat(data): integrated worker status with context and loading component',
    parents: [
      'bee4e29'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '73fbcc4'
    ],
    isBranchTip: false
  },
  {
    hash: 'bee4e29',
    committerDate: '2024-12-12T15:31:19+00:00',
    authorDate: '2024-11-11 15:31:19 +0000',
    message: 'feat(data): implemented custom web worker for data loading and dropped external dep',
    parents: [
      'd05120c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'dab5c7b'
    ],
    isBranchTip: false
  },
  {
    hash: 'd05120c',
    committerDate: '2024-12-12T14:48:00+00:00',
    authorDate: '2024-11-11 14:48:00 +0000',
    message: 'chore(data): added extra comments and docs to the pillow export parser',
    parents: [
      '70e8695'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bee4e29'
    ],
    isBranchTip: false
  },
  {
    hash: '70e8695',
    committerDate: '2024-12-12T14:43:38+00:00',
    authorDate: '2024-11-11 14:43:38 +0000',
    message: 'feat(data): pillow export parser now supports the truly raw export with no prior modifications made',
    parents: [
      '0eeea35'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd05120c'
    ],
    isBranchTip: false
  },
  {
    hash: '0eeea35',
    committerDate: '2024-12-11T20:40:34+00:00',
    authorDate: '2024-11-10 20:40:34 +0000',
    message: 'feat(data): refactored raw data parser function to make only one pass of the file',
    parents: [
      'e0fa20a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '70e8695'
    ],
    isBranchTip: false
  },
  {
    hash: 'e0fa20a',
    committerDate: '2024-12-11T17:57:08+00:00',
    authorDate: '2024-11-10 17:57:08 +0000',
    message: 'feat(graph): sleep stage graph improvements',
    parents: [
      '6178286'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0eeea35'
    ],
    isBranchTip: false
  },
  {
    hash: '6178286',
    committerDate: '2024-12-11T17:46:07+00:00',
    authorDate: '2024-11-10 17:46:07 +0000',
    message: 'feat(graph): first pass of stacked bar chart / gantt of sleep stage breakdown',
    parents: [
      '3496d41'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e0fa20a'
    ],
    isBranchTip: false
  },
  {
    hash: '3496d41',
    committerDate: '2024-12-11T15:54:37+00:00',
    authorDate: '2024-11-10 15:54:37 +0000',
    message: 'feat(data): re-integrated worker into raw sleep data hook and added to context',
    parents: [
      '42f2132'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6178286'
    ],
    isBranchTip: false
  },
  {
    hash: '2888162',
    committerDate: '2024-12-11T15:08:53+00:00',
    authorDate: '2024-11-10 15:08:53 +0000',
    message: 'Merge pull request #20 from TomPlum/renovate/all-minor-patch',
    parents: [
      '732b304',
      '7215477'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '744a388',
      '328c273'
    ],
    isBranchTip: false
  },
  {
    hash: '42f2132',
    committerDate: '2024-12-11T14:47:12+00:00',
    authorDate: '2024-11-10 14:47:12 +0000',
    message: 'feat(data): removed redundant props from useRawSleepData hook',
    parents: [
      'bf551c0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3496d41'
    ],
    isBranchTip: false
  },
  {
    hash: 'bf551c0',
    committerDate: '2024-12-11T13:21:35+00:00',
    authorDate: '2024-11-10 13:21:35 +0000',
    message: 'feat(data): fixed sound data parsing and added sleep stage data alongside it',
    parents: [
      '29a7212'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '42f2132'
    ],
    isBranchTip: false
  },
  {
    hash: '29a7212',
    committerDate: '2024-12-11T12:40:13+00:00',
    authorDate: '2024-11-10 12:40:13 +0000',
    message: 'feat(data): consolidated raw data parsing experiment into main impl',
    parents: [
      '4c801b6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bf551c0'
    ],
    isBranchTip: false
  },
  {
    hash: '4c801b6',
    committerDate: '2024-12-10T21:23:18+00:00',
    authorDate: '2024-11-09 21:23:18 +0000',
    message: 'feat(data): parsed sound points and mapped to sessions',
    parents: [
      'ffb0337'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '29a7212'
    ],
    isBranchTip: false
  },
  {
    hash: 'ffb0337',
    committerDate: '2024-12-10T21:02:39+00:00',
    authorDate: '2024-11-09 21:02:39 +0000',
    message: 'feat(data): fixed table searching and date parsing',
    parents: [
      '5e7b005'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4c801b6'
    ],
    isBranchTip: false
  },
  {
    hash: '5e7b005',
    committerDate: '2024-12-10T20:01:39+00:00',
    authorDate: '2024-11-09 20:01:39 +0000',
    message: 'feat(data): attempting to parse raw data file',
    parents: [
      '821fe5a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ffb0337'
    ],
    isBranchTip: false
  },
  {
    hash: '7215477',
    committerDate: '2024-12-10T04:39:56+00:00',
    authorDate: '2024-11-09 04:39:56 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      '732b304'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '2888162'
    ],
    isBranchTip: false
  },
  {
    hash: '821fe5a',
    committerDate: '2024-12-06T21:18:18+00:00',
    authorDate: '2024-11-05 21:18:18 +0000',
    message: 'chore(docs): README ToC',
    parents: [
      '732b304'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5e7b005'
    ],
    isBranchTip: false
  },
  {
    hash: '732b304',
    committerDate: '2024-12-05T19:46:19+00:00',
    authorDate: '2024-11-04 19:46:19 +0000',
    message: 'Merge pull request #23 from TomPlum/develop',
    parents: [
      'fbca587',
      'b2bf478'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2888162',
      '7215477',
      '821fe5a'
    ],
    isBranchTip: false
  },
  {
    hash: 'b2bf478',
    committerDate: '2024-12-05T19:45:58+00:00',
    authorDate: '2024-11-04 19:45:58 +0000',
    message: 'fix(graph): fixed static asset loading in production mode',
    parents: [
      '4410cd7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '732b304'
    ],
    isBranchTip: false
  },
  {
    hash: 'fbca587',
    committerDate: '2024-12-05T19:31:29+00:00',
    authorDate: '2024-11-04 19:31:29 +0000',
    message: 'Merge pull request #22 from TomPlum/develop',
    parents: [
      'ff20995',
      '4410cd7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '732b304'
    ],
    isBranchTip: false
  },
  {
    hash: '4410cd7',
    committerDate: '2024-12-05T19:31:08+00:00',
    authorDate: '2024-11-04 19:31:08 +0000',
    message: 'test(data): fixed compilation error in useLinearRegression.spec.ts',
    parents: [
      'e8c2bfb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b2bf478',
      'fbca587'
    ],
    isBranchTip: false
  },
  {
    hash: 'ff20995',
    committerDate: '2024-12-05T19:29:24+00:00',
    authorDate: '2024-11-04 19:29:24 +0000',
    message: 'Merge pull request #21 from TomPlum/develop',
    parents: [
      '529c117',
      'e8c2bfb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fbca587'
    ],
    isBranchTip: false
  },
  {
    hash: 'e8c2bfb',
    committerDate: '2024-12-04T18:35:05+00:00',
    authorDate: '2024-11-03 18:35:05 +0000',
    message: 'feat(graph): updated active session info to use pillow logo instead of text',
    parents: [
      '4d7a7e9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4410cd7',
      'ff20995'
    ],
    isBranchTip: false
  },
  {
    hash: '4d7a7e9',
    committerDate: '2024-12-04T09:41:53+00:00',
    authorDate: '2024-11-03 09:41:53 +0000',
    message: 'feat(graph): added day of the week name to the tooltip session date format',
    parents: [
      '69eaadc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e8c2bfb'
    ],
    isBranchTip: false
  },
  {
    hash: '69eaadc',
    committerDate: '2024-12-04T09:39:56+00:00',
    authorDate: '2024-11-03 09:39:56 +0000',
    message: 'chore(data): updated sleep data to most recent csv snapshot',
    parents: [
      'c31f162'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4d7a7e9'
    ],
    isBranchTip: false
  },
  {
    hash: 'c31f162',
    committerDate: '2024-12-01T20:02:36+00:00',
    authorDate: '2024-10-31 20:02:36 +0000',
    message: 'feat(graph): minor styling improvements to active session info and stacked graph placeholder',
    parents: [
      '98ff75e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '69eaadc'
    ],
    isBranchTip: false
  },
  {
    hash: '98ff75e',
    committerDate: '2024-11-30T20:21:01+00:00',
    authorDate: '2024-10-30 20:21:01 +0000',
    message: 'feat(graph): added pillows website link to the active session info component',
    parents: [
      '7e8868b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c31f162'
    ],
    isBranchTip: false
  },
  {
    hash: '7e8868b',
    committerDate: '2024-11-30T20:15:09+00:00',
    authorDate: '2024-10-30 20:15:09 +0000',
    message: 'feat(graph): added descriptions of sleep metrics upon hover in stacked view',
    parents: [
      '51f121d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '98ff75e'
    ],
    isBranchTip: false
  },
  {
    hash: '51f121d',
    committerDate: '2024-11-30T19:51:40+00:00',
    authorDate: '2024-10-30 19:51:40 +0000',
    message: 'Merge branch \'release\' into develop',
    parents: [
      '21678c9',
      '529c117'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7e8868b'
    ],
    isBranchTip: false
  },
  {
    hash: '529c117',
    committerDate: '2024-11-30T19:51:30+00:00',
    authorDate: '2024-10-30 19:51:30 +0000',
    message: 'Merge pull request #16 from TomPlum/renovate/all-minor-patch',
    parents: [
      '0d12d74',
      '5765026'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ff20995',
      '51f121d'
    ],
    isBranchTip: false
  },
  {
    hash: '5765026',
    committerDate: '2024-11-30T15:18:13+00:00',
    authorDate: '2024-10-30 15:18:13 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      '0d12d74'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '529c117'
    ],
    isBranchTip: false
  },
  {
    hash: '21678c9',
    committerDate: '2024-11-27T19:38:06+00:00',
    authorDate: '2024-10-27 19:38:06 +0000',
    message: 'chore(graph): extracted useDefaultQueryParams hook from sleep context provider',
    parents: [
      'e6ea316'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '51f121d'
    ],
    isBranchTip: false
  },
  {
    hash: 'e6ea316',
    committerDate: '2024-11-27T19:30:38+00:00',
    authorDate: '2024-10-27 19:30:38 +0000',
    message: 'chore(graph): changed default date range query params to all data instead of recent',
    parents: [
      'f7116d9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '21678c9'
    ],
    isBranchTip: false
  },
  {
    hash: 'f7116d9',
    committerDate: '2024-11-27T19:28:45+00:00',
    authorDate: '2024-10-27 19:28:45 +0000',
    message: 'chore(graph): increased typical sessions healthy awake time range to 0-10%',
    parents: [
      '87efebe'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e6ea316'
    ],
    isBranchTip: false
  },
  {
    hash: '87efebe',
    committerDate: '2024-11-27T19:25:00+00:00',
    authorDate: '2024-10-27 19:25:00 +0000',
    message: 'fix(graph): duration breakdown pie chart no longer renders labels for 0% values',
    parents: [
      'd638b1e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f7116d9'
    ],
    isBranchTip: false
  },
  {
    hash: 'd638b1e',
    committerDate: '2024-11-27T18:55:58+00:00',
    authorDate: '2024-10-27 18:55:58 +0000',
    message: 'feat(graph): added mood emoji to the session tooltip',
    parents: [
      '928a7f4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '87efebe'
    ],
    isBranchTip: false
  },
  {
    hash: '928a7f4',
    committerDate: '2024-11-23T13:14:39+00:00',
    authorDate: '2024-10-23 13:14:39 +0100',
    message: 'feat(graph): reduced active dot radius for active session counts between 100 and 300',
    parents: [
      'd401424'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd638b1e'
    ],
    isBranchTip: false
  },
  {
    hash: 'd401424',
    committerDate: '2024-11-23T13:08:07+00:00',
    authorDate: '2024-10-23 13:08:07 +0100',
    message: 'fix(graph): fixed stacked view toggle not updating query param when checking',
    parents: [
      '2f85544'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '928a7f4'
    ],
    isBranchTip: false
  },
  {
    hash: '0d12d74',
    committerDate: '2024-11-23T12:46:10+00:00',
    authorDate: '2024-10-23 12:46:10 +0100',
    message: 'Merge pull request #19 from TomPlum/develop',
    parents: [
      '5e1e15c',
      '2f85544'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '529c117',
      '5765026'
    ],
    isBranchTip: false
  },
  {
    hash: '2f85544',
    committerDate: '2024-11-23T12:40:38+00:00',
    authorDate: '2024-10-23 12:40:38 +0100',
    message: 'Merge pull request #18 from TomPlum/feature/stacked-view',
    parents: [
      'a6ba004',
      '2c5082d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd401424',
      '0d12d74'
    ],
    isBranchTip: false
  },
  {
    hash: '2c5082d',
    committerDate: '2024-11-23T12:39:13+00:00',
    authorDate: '2024-10-23 12:39:13 +0100',
    message: 'feat(graph): stacked toggle now clears stacked metrics when turning on',
    parents: [
      '9676781'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2f85544'
    ],
    isBranchTip: false
  },
  {
    hash: '9676781',
    committerDate: '2024-11-23T12:33:26+00:00',
    authorDate: '2024-10-23 12:33:26 +0100',
    message: 'fix(config): trying to make vite HMR watch the public dir during local development',
    parents: [
      '317a526'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2c5082d'
    ],
    isBranchTip: false
  },
  {
    hash: '317a526',
    committerDate: '2024-11-23T12:22:32+00:00',
    authorDate: '2024-10-23 12:22:32 +0100',
    message: 'feat(graph): fixed stacked graph placeholder messages and ensured metric checkboxes update the query params',
    parents: [
      '66ac076'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9676781'
    ],
    isBranchTip: false
  },
  {
    hash: '66ac076',
    committerDate: '2024-11-22T20:27:41+00:00',
    authorDate: '2024-10-22 20:27:41 +0100',
    message: 'fix(graph): fixed missing tooltip and improvement label from single graph view',
    parents: [
      '415c1d1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '317a526'
    ],
    isBranchTip: false
  },
  {
    hash: '415c1d1',
    committerDate: '2024-11-22T20:18:29+00:00',
    authorDate: '2024-10-22 20:18:29 +0100',
    message: 'feat(graph): improvement line label and tooltip no longer render twice in stacked view',
    parents: [
      'c0dc79f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '66ac076'
    ],
    isBranchTip: false
  },
  {
    hash: 'c0dc79f',
    committerDate: '2024-11-22T20:13:21+00:00',
    authorDate: '2024-10-22 20:13:21 +0100',
    message: 'feat(graph): active sessions info now respects stacked view with no selections',
    parents: [
      '0b9fad5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '415c1d1'
    ],
    isBranchTip: false
  },
  {
    hash: '0b9fad5',
    committerDate: '2024-11-22T20:08:53+00:00',
    authorDate: '2024-10-22 20:08:53 +0100',
    message: 'fix(graph): fixed react hooks lifecycle error with stacked graphs',
    parents: [
      '70164f4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c0dc79f'
    ],
    isBranchTip: false
  },
  {
    hash: '70164f4',
    committerDate: '2024-11-22T19:38:40+00:00',
    authorDate: '2024-10-22 19:38:40 +0100',
    message: 'chore(graph): split metric checkbox component into two for separation of concerns',
    parents: [
      'bb29e00'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0b9fad5'
    ],
    isBranchTip: false
  },
  {
    hash: 'bb29e00',
    committerDate: '2024-11-22T17:33:45+00:00',
    authorDate: '2024-10-22 17:33:45 +0100',
    message: 'feat(graph): metric checkbox now has button mode and graph placeholder improved button styling',
    parents: [
      '6487f34'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '70164f4'
    ],
    isBranchTip: false
  },
  {
    hash: '6487f34',
    committerDate: '2024-11-22T15:38:58+00:00',
    authorDate: '2024-10-22 15:38:58 +0100',
    message: 'feat(routing): serialised stacked view boolean in query params',
    parents: [
      '18fdb81'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bb29e00'
    ],
    isBranchTip: false
  },
  {
    hash: '18fdb81',
    committerDate: '2024-11-22T15:13:33+00:00',
    authorDate: '2024-10-22 15:13:33 +0100',
    message: 'feat(graph): metric config no longer lets you pick more than 3 metrics in stacked view',
    parents: [
      'e33383e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6487f34'
    ],
    isBranchTip: false
  },
  {
    hash: 'e33383e',
    committerDate: '2024-11-22T15:10:35+00:00',
    authorDate: '2024-10-22 15:10:35 +0100',
    message: 'feat(graph): stacked graph placeholder now offer available sleep metrics to pick from',
    parents: [
      '77adf46'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '18fdb81'
    ],
    isBranchTip: false
  },
  {
    hash: '77adf46',
    committerDate: '2024-11-22T14:59:15+00:00',
    authorDate: '2024-10-22 14:59:15 +0100',
    message: 'chore(graph): extracted stacked graph placeholder component',
    parents: [
      '1d30e95'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e33383e'
    ],
    isBranchTip: false
  },
  {
    hash: '1d30e95',
    committerDate: '2024-11-22T13:49:05+00:00',
    authorDate: '2024-10-22 13:49:05 +0100',
    message: 'feat(graph): second graph in stacked view now transitions its opacity as it renders',
    parents: [
      'd453692'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '77adf46'
    ],
    isBranchTip: false
  },
  {
    hash: 'd453692',
    committerDate: '2024-11-22T12:59:58+00:00',
    authorDate: '2024-10-22 12:59:58 +0100',
    message: 'feat(graph): reduced the upper-bound of the dynamic y-axis domain to better frame the data on the chart',
    parents: [
      '7ef626b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1d30e95'
    ],
    isBranchTip: false
  },
  {
    hash: '7ef626b',
    committerDate: '2024-11-22T12:57:30+00:00',
    authorDate: '2024-10-22 12:57:30 +0100',
    message: 'feat(graph): added selection placeholder when a second metric is not selected in stacked view',
    parents: [
      'b7851b4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd453692'
    ],
    isBranchTip: false
  },
  {
    hash: 'b7851b4',
    committerDate: '2024-11-22T09:56:43+00:00',
    authorDate: '2024-10-22 09:56:43 +0100',
    message: 'feat(graph): favicon now changes based on active sleep metric',
    parents: [
      '569f1d0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7ef626b'
    ],
    isBranchTip: false
  },
  {
    hash: '569f1d0',
    committerDate: '2024-11-22T09:28:15+00:00',
    authorDate: '2024-10-22 09:28:15 +0100',
    message: 'feat(graph): added text to stacked view toggle button',
    parents: [
      '72634f1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b7851b4'
    ],
    isBranchTip: false
  },
  {
    hash: '72634f1',
    committerDate: '2024-11-22T09:20:51+00:00',
    authorDate: '2024-10-22 09:20:51 +0100',
    message: 'feat(graph): fixed non-stacked view and added dynamic stacked colours to active session info',
    parents: [
      '6b2dfb3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '569f1d0'
    ],
    isBranchTip: false
  },
  {
    hash: '6b2dfb3',
    committerDate: '2024-11-21T17:24:29+00:00',
    authorDate: '2024-10-21 17:24:29 +0100',
    message: 'feat(graph): first pass of enabling stacked graphs',
    parents: [
      'a6ba004'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '72634f1'
    ],
    isBranchTip: false
  },
  {
    hash: 'a6ba004',
    committerDate: '2024-11-21T16:35:40+00:00',
    authorDate: '2024-10-21 16:35:40 +0100',
    message: 'chore(graph): renamed old graph to 3D',
    parents: [
      '9de61dd'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2f85544',
      '6b2dfb3'
    ],
    isBranchTip: false
  },
  {
    hash: '9de61dd',
    committerDate: '2024-11-21T16:34:23+00:00',
    authorDate: '2024-10-21 16:34:23 +0100',
    message: 'Merge branch \'release\' into develop',
    parents: [
      'e9d14e5',
      '5e1e15c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a6ba004'
    ],
    isBranchTip: false
  },
  {
    hash: 'e9d14e5',
    committerDate: '2024-11-21T16:34:13+00:00',
    authorDate: '2024-10-21 16:34:13 +0100',
    message: 'chore(docs): added some TODOs to the README',
    parents: [
      '61b38d9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9de61dd'
    ],
    isBranchTip: false
  },
  {
    hash: '5e1e15c',
    committerDate: '2024-11-21T11:41:21+00:00',
    authorDate: '2024-10-21 11:41:21 +0100',
    message: 'Merge pull request #17 from TomPlum/develop',
    parents: [
      '7d545a5',
      '61b38d9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0d12d74',
      '9de61dd'
    ],
    isBranchTip: false
  },
  {
    hash: '61b38d9',
    committerDate: '2024-11-21T10:46:02+00:00',
    authorDate: '2024-10-21 10:46:02 +0100',
    message: 'feat(graph): session count colour now transitions with same animation duration as graph',
    parents: [
      'a2db943'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e9d14e5',
      '5e1e15c'
    ],
    isBranchTip: false
  },
  {
    hash: 'a2db943',
    committerDate: '2024-11-21T10:44:52+00:00',
    authorDate: '2024-10-21 10:44:52 +0100',
    message: 'feat(graph): data source now links to a download of the raw CSV',
    parents: [
      '5a21429'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '61b38d9'
    ],
    isBranchTip: false
  },
  {
    hash: '5a21429',
    committerDate: '2024-11-21T10:35:42+00:00',
    authorDate: '2024-10-21 10:35:42 +0100',
    message: 'feat(graph): added data source version to active session info',
    parents: [
      'a5425d1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a2db943'
    ],
    isBranchTip: false
  },
  {
    hash: 'a5425d1',
    committerDate: '2024-11-21T10:27:09+00:00',
    authorDate: '2024-10-21 10:27:09 +0100',
    message: 'chore(graph): extracted active session info component from sleep page',
    parents: [
      '2282d36'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5a21429'
    ],
    isBranchTip: false
  },
  {
    hash: '2282d36',
    committerDate: '2024-11-21T10:22:42+00:00',
    authorDate: '2024-10-21 10:22:42 +0100',
    message: 'chore(graph): increased font weight of improvement label text',
    parents: [
      'cba1df6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a5425d1'
    ],
    isBranchTip: false
  },
  {
    hash: 'cba1df6',
    committerDate: '2024-11-20T11:18:32+00:00',
    authorDate: '2024-10-20 11:18:32 +0100',
    message: 'feat(graph): added subtle cartesian grid back to the line chart',
    parents: [
      'da988de'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2282d36'
    ],
    isBranchTip: false
  },
  {
    hash: 'da988de',
    committerDate: '2024-11-20T11:06:32+00:00',
    authorDate: '2024-10-20 11:06:32 +0100',
    message: 'fix(graph): a single month can now be selected from the date picker',
    parents: [
      'edafbbf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'cba1df6'
    ],
    isBranchTip: false
  },
  {
    hash: 'edafbbf',
    committerDate: '2024-11-20T10:55:50+00:00',
    authorDate: '2024-10-20 10:55:50 +0100',
    message: 'Merge branch \'release\' into develop',
    parents: [
      'afd8749',
      '7d545a5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'da988de'
    ],
    isBranchTip: false
  },
  {
    hash: 'afd8749',
    committerDate: '2024-11-20T10:54:55+00:00',
    authorDate: '2024-10-20 10:54:55 +0100',
    message: 'chore(graph): tweaked active dot radius for the main sleep metric line',
    parents: [
      'cee6402'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'edafbbf'
    ],
    isBranchTip: false
  },
  {
    hash: 'cee6402',
    committerDate: '2024-11-20T10:49:13+00:00',
    authorDate: '2024-10-20 10:49:13 +0100',
    message: 'chore(graph): hoisted improvement date calculation into sleep context',
    parents: [
      '012ffe9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'afd8749'
    ],
    isBranchTip: false
  },
  {
    hash: '012ffe9',
    committerDate: '2024-11-20T10:45:23+00:00',
    authorDate: '2024-10-20 10:45:23 +0100',
    message: 'feat(graph): improved session and nap filtering',
    parents: [
      'bff2088'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'cee6402'
    ],
    isBranchTip: false
  },
  {
    hash: 'bff2088',
    committerDate: '2024-11-19T19:18:37+00:00',
    authorDate: '2024-10-19 19:18:37 +0100',
    message: 'feat(routing): added language to query parameters',
    parents: [
      '21fecc1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '012ffe9'
    ],
    isBranchTip: false
  },
  {
    hash: '21fecc1',
    committerDate: '2024-11-19T19:10:25+00:00',
    authorDate: '2024-10-19 19:10:25 +0100',
    message: 'feat(graph): show all button now changes to "recent" if all sessions are showing',
    parents: [
      '9136c6b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bff2088'
    ],
    isBranchTip: false
  },
  {
    hash: '7d545a5',
    committerDate: '2024-11-19T19:01:32+00:00',
    authorDate: '2024-10-19 19:01:32 +0100',
    message: 'Merge pull request #14 from TomPlum/renovate/all-minor-patch',
    parents: [
      '3d3d5a2',
      'e27d91a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5e1e15c',
      'edafbbf'
    ],
    isBranchTip: false
  },
  {
    hash: '9136c6b',
    committerDate: '2024-11-19T15:36:18+00:00',
    authorDate: '2024-10-19 15:36:18 +0100',
    message: 'feat(graph): added show all button and extracted date selection hook',
    parents: [
      '7fc3850'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '21fecc1'
    ],
    isBranchTip: false
  },
  {
    hash: '7fc3850',
    committerDate: '2024-11-19T15:21:51+00:00',
    authorDate: '2024-10-19 15:21:51 +0100',
    message: 'chore(graph): extracted graph controls component',
    parents: [
      '7c9d0e2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9136c6b'
    ],
    isBranchTip: false
  },
  {
    hash: '7c9d0e2',
    committerDate: '2024-11-19T15:17:59+00:00',
    authorDate: '2024-10-19 15:17:59 +0100',
    message: 'fix(data): filtered out sessions longer than 15 hours',
    parents: [
      '91ab124'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7fc3850'
    ],
    isBranchTip: false
  },
  {
    hash: '91ab124',
    committerDate: '2024-11-19T15:12:54+00:00',
    authorDate: '2024-10-19 15:12:54 +0100',
    message: 'feat(graph): added vertical reference line for the date in which I made improvements',
    parents: [
      'b9e9eaf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7c9d0e2'
    ],
    isBranchTip: false
  },
  {
    hash: '3d3d5a2',
    committerDate: '2024-11-19T12:44:33+00:00',
    authorDate: '2024-10-19 12:44:33 +0100',
    message: 'Merge pull request #15 from TomPlum/develop',
    parents: [
      'c9c48c0',
      'b9e9eaf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7d545a5'
    ],
    isBranchTip: false
  },
  {
    hash: 'b9e9eaf',
    committerDate: '2024-11-19T12:43:46+00:00',
    authorDate: '2024-10-19 12:43:46 +0100',
    message: 'chore(test): fixed failing unit tests due to bad setup data',
    parents: [
      '1634ce3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '91ab124',
      '3d3d5a2'
    ],
    isBranchTip: false
  },
  {
    hash: '1634ce3',
    committerDate: '2024-11-19T12:40:59+00:00',
    authorDate: '2024-10-19 12:40:59 +0100',
    message: 'feat(graph): moved locale switch to top right controls and extracted component',
    parents: [
      'fcc0e1c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b9e9eaf'
    ],
    isBranchTip: false
  },
  {
    hash: 'fcc0e1c',
    committerDate: '2024-11-19T12:26:20+00:00',
    authorDate: '2024-10-19 12:26:20 +0100',
    message: 'chore(docs): added screenshots to README',
    parents: [
      'ef2cfc2'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1634ce3'
    ],
    isBranchTip: false
  },
  {
    hash: 'ef2cfc2',
    committerDate: '2024-11-19T12:21:14+00:00',
    authorDate: '2024-10-19 12:21:14 +0100',
    message: 'feat(graph): added nap indicator to session tooltip',
    parents: [
      '76a2a2e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fcc0e1c'
    ],
    isBranchTip: false
  },
  {
    hash: '76a2a2e',
    committerDate: '2024-11-19T12:11:57+00:00',
    authorDate: '2024-10-19 12:11:57 +0100',
    message: 'fix(routing): fixed bad query param name for sleep metric',
    parents: [
      '3f4402f'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ef2cfc2'
    ],
    isBranchTip: false
  },
  {
    hash: '3f4402f',
    committerDate: '2024-11-19T12:04:44+00:00',
    authorDate: '2024-10-19 12:04:44 +0100',
    message: 'feat(graph): added duration as a percentage of 8 hours as a new metric',
    parents: [
      '184b081'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '76a2a2e'
    ],
    isBranchTip: false
  },
  {
    hash: 'e27d91a',
    committerDate: '2024-11-19T05:30:16+00:00',
    authorDate: '2024-10-19 04:30:16 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      'c9c48c0'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '7d545a5'
    ],
    isBranchTip: false
  },
  {
    hash: 'c9c48c0',
    committerDate: '2024-11-18T16:29:29+00:00',
    authorDate: '2024-10-18 16:29:29 +0100',
    message: 'Merge pull request #13 from TomPlum/develop',
    parents: [
      '5f4518b',
      '184b081'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3d3d5a2',
      'e27d91a'
    ],
    isBranchTip: false
  },
  {
    hash: '184b081',
    committerDate: '2024-11-18T16:28:37+00:00',
    authorDate: '2024-10-18 16:28:37 +0100',
    message: 'chore(test): fixed failing unit tests for useLinearRegression.spec.ts',
    parents: [
      'eda1f0d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3f4402f',
      'c9c48c0'
    ],
    isBranchTip: false
  },
  {
    hash: 'eda1f0d',
    committerDate: '2024-11-18T16:24:57+00:00',
    authorDate: '2024-10-18 16:24:57 +0100',
    message: 'feat(graph): added github button to top left controls container',
    parents: [
      'b89ac17'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '184b081'
    ],
    isBranchTip: false
  },
  {
    hash: 'b89ac17',
    committerDate: '2024-11-18T11:32:53+00:00',
    authorDate: '2024-10-18 11:32:53 +0100',
    message: 'chore(styling): minor styling and font changes',
    parents: [
      '15c8018'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eda1f0d'
    ],
    isBranchTip: false
  },
  {
    hash: '15c8018',
    committerDate: '2024-11-17T20:18:02+00:00',
    authorDate: '2024-10-17 20:18:02 +0100',
    message: 'chore(graph): extracted regression delta label component from graph',
    parents: [
      'b4a80bb'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b89ac17'
    ],
    isBranchTip: false
  },
  {
    hash: 'b4a80bb',
    committerDate: '2024-11-17T20:13:11+00:00',
    authorDate: '2024-10-17 20:13:11 +0100',
    message: 'feat(graph): regression line delta horizontal reference line now animates like its vertical counterpart',
    parents: [
      'e748aef'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '15c8018'
    ],
    isBranchTip: false
  },
  {
    hash: 'e748aef',
    committerDate: '2024-11-17T19:50:26+00:00',
    authorDate: '2024-10-17 19:50:26 +0100',
    message: 'feat(graph): regression line delta vertical reference line now fits the correct y-ordinates and doesn\'t fill the charts height',
    parents: [
      '46cfb4d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b4a80bb'
    ],
    isBranchTip: false
  },
  {
    hash: '46cfb4d',
    committerDate: '2024-11-17T18:15:51+00:00',
    authorDate: '2024-10-17 18:15:51 +0100',
    message: 'chore(graph): encapsulated reference area fill into hook and tweaks reference line stroke dash',
    parents: [
      'aaa16bf'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e748aef'
    ],
    isBranchTip: false
  },
  {
    hash: 'aaa16bf',
    committerDate: '2024-11-17T18:00:20+00:00',
    authorDate: '2024-10-17 18:00:20 +0100',
    message: 'chore(docs): removed readme template contents',
    parents: [
      '05b7c89'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '46cfb4d'
    ],
    isBranchTip: false
  },
  {
    hash: '05b7c89',
    committerDate: '2024-11-17T17:58:06+00:00',
    authorDate: '2024-10-17 17:58:06 +0100',
    message: 'chore(lint): added import eslint plugin, configured and fixed import extensions',
    parents: [
      '19e0968'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'aaa16bf'
    ],
    isBranchTip: false
  },
  {
    hash: '19e0968',
    committerDate: '2024-11-17T17:51:00+00:00',
    authorDate: '2024-10-17 17:51:00 +0100',
    message: 'chore(lint): tweaked quotes rules and fixed all double -> single',
    parents: [
      '245c95a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '05b7c89'
    ],
    isBranchTip: false
  },
  {
    hash: '245c95a',
    committerDate: '2024-11-17T17:50:04+00:00',
    authorDate: '2024-10-17 17:50:04 +0100',
    message: 'chore(lint): tweaked object/curly brace rules and fixed all spacing issues',
    parents: [
      'ddca752'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '19e0968'
    ],
    isBranchTip: false
  },
  {
    hash: 'ddca752',
    committerDate: '2024-11-17T17:48:04+00:00',
    authorDate: '2024-10-17 17:48:04 +0100',
    message: 'chore(lint): tweaked semi rules and removed redundant semicolons',
    parents: [
      'f32e3d4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '245c95a'
    ],
    isBranchTip: false
  },
  {
    hash: 'f32e3d4',
    committerDate: '2024-11-17T16:42:11+00:00',
    authorDate: '2024-10-17 16:42:11 +0100',
    message: 'Revert "chore(data): removed redundant guarding in linear regression hook"',
    parents: [
      '01068d1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ddca752'
    ],
    isBranchTip: false
  },
  {
    hash: '01068d1',
    committerDate: '2024-11-17T16:41:32+00:00',
    authorDate: '2024-10-17 16:41:32 +0100',
    message: 'chore(data): removed redundant guarding in linear regression hook',
    parents: [
      'c61415e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f32e3d4'
    ],
    isBranchTip: false
  },
  {
    hash: 'c61415e',
    committerDate: '2024-11-17T16:34:33+00:00',
    authorDate: '2024-10-17 16:34:33 +0100',
    message: 'chore(data): filtered out invalid awake time values',
    parents: [
      '66a1d30'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '01068d1'
    ],
    isBranchTip: false
  },
  {
    hash: '66a1d30',
    committerDate: '2024-11-17T16:30:39+00:00',
    authorDate: '2024-10-17 16:30:39 +0100',
    message: 'feat(graph): migrated xAxisInterval to axes hook and added one more level of granularity',
    parents: [
      '76baba0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c61415e'
    ],
    isBranchTip: false
  },
  {
    hash: '5f4518b',
    committerDate: '2024-11-17T16:21:40+00:00',
    authorDate: '2024-10-17 16:21:40 +0100',
    message: 'Merge pull request #12 from TomPlum/develop',
    parents: [
      '34aa1bf',
      '76baba0'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c9c48c0'
    ],
    isBranchTip: false
  },
  {
    hash: '76baba0',
    committerDate: '2024-11-17T16:21:03+00:00',
    authorDate: '2024-10-17 16:21:03 +0100',
    message: 'feat(locale): default locale and switch position is now en',
    parents: [
      'ae9b6bc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '66a1d30',
      '5f4518b'
    ],
    isBranchTip: false
  },
  {
    hash: 'ae9b6bc',
    committerDate: '2024-11-17T16:19:51+00:00',
    authorDate: '2024-10-17 16:19:51 +0100',
    message: 'feat(graph): custom x tick now offsets first/last date strings to fit on screen',
    parents: [
      '924c8f9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '76baba0'
    ],
    isBranchTip: false
  },
  {
    hash: '924c8f9',
    committerDate: '2024-11-17T16:12:38+00:00',
    authorDate: '2024-10-17 16:12:38 +0100',
    message: 'chore(data): extracted axes 2d hook',
    parents: [
      '8abcdd6'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ae9b6bc'
    ],
    isBranchTip: false
  },
  {
    hash: '8abcdd6',
    committerDate: '2024-11-17T16:04:33+00:00',
    authorDate: '2024-10-17 16:04:33 +0100',
    message: 'chore(data): hoisted earliest/latest active session dates into context and integrated with x-axis domain',
    parents: [
      'd4d645a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '924c8f9'
    ],
    isBranchTip: false
  },
  {
    hash: 'd4d645a',
    committerDate: '2024-11-17T15:30:01+00:00',
    authorDate: '2024-10-17 15:30:01 +0100',
    message: 'feat(data): reworked linear regression algorithm and x-axis domain to work better with dates and ensure line of best fit is linear',
    parents: [
      '7a78b8d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '8abcdd6'
    ],
    isBranchTip: false
  },
  {
    hash: '7a78b8d',
    committerDate: '2024-11-17T11:25:24+00:00',
    authorDate: '2024-10-17 11:25:24 +0100',
    message: 'test(data): added linear regression hook unit tests and shortened english translations',
    parents: [
      '827a805'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd4d645a'
    ],
    isBranchTip: false
  },
  {
    hash: '34aa1bf',
    committerDate: '2024-11-16T10:46:32+00:00',
    authorDate: '2024-10-16 10:46:32 +0100',
    message: 'Merge pull request #11 from TomPlum/develop',
    parents: [
      '6a66ec6',
      '827a805'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5f4518b'
    ],
    isBranchTip: false
  },
  {
    hash: '827a805',
    committerDate: '2024-11-16T10:45:53+00:00',
    authorDate: '2024-10-16 10:45:53 +0100',
    message: 'feat(routing): re-added sleep route to app navigation and added dynamic baseUrl based on mode',
    parents: [
      '5ef49a3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7a78b8d',
      '34aa1bf'
    ],
    isBranchTip: false
  },
  {
    hash: '6a66ec6',
    committerDate: '2024-11-16T10:38:22+00:00',
    authorDate: '2024-10-16 10:38:22 +0100',
    message: 'Merge pull request #10 from TomPlum/develop',
    parents: [
      '46a65f9',
      '5ef49a3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '34aa1bf'
    ],
    isBranchTip: false
  },
  {
    hash: '5ef49a3',
    committerDate: '2024-11-16T10:37:53+00:00',
    authorDate: '2024-10-16 10:37:53 +0100',
    message: 'feat(graph): added language toggle button',
    parents: [
      '3270ffd'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '827a805',
      '6a66ec6'
    ],
    isBranchTip: false
  },
  {
    hash: '46a65f9',
    committerDate: '2024-11-15T18:50:48+00:00',
    authorDate: '2024-10-15 18:50:48 +0100',
    message: 'Merge pull request #9 from TomPlum/develop',
    parents: [
      '7125412',
      '3270ffd'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6a66ec6'
    ],
    isBranchTip: false
  },
  {
    hash: '3270ffd',
    committerDate: '2024-11-15T18:49:22+00:00',
    authorDate: '2024-10-15 18:49:22 +0100',
    message: 'feat(graph): added duration to the tooltip',
    parents: [
      'fb7455a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5ef49a3',
      '46a65f9'
    ],
    isBranchTip: false
  },
  {
    hash: 'fb7455a',
    committerDate: '2024-11-15T18:43:22+00:00',
    authorDate: '2024-10-15 18:43:22 +0100',
    message: 'feat(graph): added healthy data range for sleep quality metric',
    parents: [
      '1606c57'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3270ffd'
    ],
    isBranchTip: false
  },
  {
    hash: '1606c57',
    committerDate: '2024-11-15T18:22:41+00:00',
    authorDate: '2024-10-15 18:22:41 +0100',
    message: 'chore(graph): session count now renders in the current metric colour',
    parents: [
      '5408eb4'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fb7455a'
    ],
    isBranchTip: false
  },
  {
    hash: '5408eb4',
    committerDate: '2024-11-15T16:52:42+00:00',
    authorDate: '2024-10-15 16:52:42 +0100',
    message: 'chore(graph): tweaked healthy ranges and added translations for session count',
    parents: [
      'adaf340'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1606c57'
    ],
    isBranchTip: false
  },
  {
    hash: 'adaf340',
    committerDate: '2024-11-15T16:45:46+00:00',
    authorDate: '2024-10-15 16:45:46 +0100',
    message: 'chore(styles): added antd dark theme and added total sessions to top left',
    parents: [
      '95dcf41'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5408eb4'
    ],
    isBranchTip: false
  },
  {
    hash: '95dcf41',
    committerDate: '2024-11-15T16:37:33+00:00',
    authorDate: '2024-10-15 16:37:33 +0100',
    message: 'feat(graph): added label to typical session area and added missing jp translations',
    parents: [
      '28293da'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'adaf340'
    ],
    isBranchTip: false
  },
  {
    hash: '28293da',
    committerDate: '2024-11-15T16:26:56+00:00',
    authorDate: '2024-10-15 16:26:56 +0100',
    message: 'chore(graph): removed enum index signatures in sleep graph datum interface and removed casting',
    parents: [
      'c27bf01'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '95dcf41'
    ],
    isBranchTip: false
  },
  {
    hash: 'c27bf01',
    committerDate: '2024-11-15T16:07:11+00:00',
    authorDate: '2024-10-15 16:07:11 +0100',
    message: 'feat(graph): added custom domain and ticks so the y domain is wrapped tighter around the value range',
    parents: [
      'eb84e73'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '28293da'
    ],
    isBranchTip: false
  },
  {
    hash: 'eb84e73',
    committerDate: '2024-11-15T15:45:53+00:00',
    authorDate: '2024-10-15 15:45:53 +0100',
    message: 'feat(graph): 2d line graph now renders right up against the left viewport edge',
    parents: [
      '1a19a6a'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c27bf01'
    ],
    isBranchTip: false
  },
  {
    hash: '1a19a6a',
    committerDate: '2024-11-15T14:40:52+00:00',
    authorDate: '2024-10-15 14:40:52 +0100',
    message: 'chore(graph): extracted typical sleep session hook for area data',
    parents: [
      'e28e441'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eb84e73'
    ],
    isBranchTip: false
  },
  {
    hash: 'e28e441',
    committerDate: '2024-11-15T14:33:17+00:00',
    authorDate: '2024-10-15 14:33:17 +0100',
    message: 'chore(graph): encapsulated properties into linear regression hook',
    parents: [
      '7f58f11'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1a19a6a'
    ],
    isBranchTip: false
  },
  {
    hash: '7f58f11',
    committerDate: '2024-11-15T14:30:56+00:00',
    authorDate: '2024-10-15 14:30:56 +0100',
    message: 'chore(graph): moved linear regression line delta reference lines into hook',
    parents: [
      'b854f35'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e28e441'
    ],
    isBranchTip: false
  },
  {
    hash: 'b854f35',
    committerDate: '2024-11-15T14:24:51+00:00',
    authorDate: '2024-10-15 14:24:51 +0100',
    message: 'feat(graph): added typical sleep session reference areas',
    parents: [
      'ddc31b5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7f58f11'
    ],
    isBranchTip: false
  },
  {
    hash: 'ddc31b5',
    committerDate: '2024-11-15T13:40:21+00:00',
    authorDate: '2024-10-15 13:40:21 +0100',
    message: 'feat(graph): added reference lines to show regression delta',
    parents: [
      '7e82560'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b854f35'
    ],
    isBranchTip: false
  },
  {
    hash: '7e82560',
    committerDate: '2024-11-15T11:06:18+00:00',
    authorDate: '2024-10-15 11:06:18 +0100',
    message: 'chore(hooks): moved more graph styling logic into a hook',
    parents: [
      '55c405d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ddc31b5'
    ],
    isBranchTip: false
  },
  {
    hash: '7125412',
    committerDate: '2024-11-15T10:31:01+00:00',
    authorDate: '2024-10-15 10:31:01 +0100',
    message: 'Merge pull request #8 from TomPlum/develop',
    parents: [
      '3cf1df4',
      '55c405d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '46a65f9'
    ],
    isBranchTip: false
  },
  {
    hash: '55c405d',
    committerDate: '2024-11-15T10:29:58+00:00',
    authorDate: '2024-10-15 10:29:58 +0100',
    message: 'feat(routing): removed internal use of /sleep in favour of / since gh-pages hosts at /sleep anyway',
    parents: [
      '758174d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7e82560',
      '7125412'
    ],
    isBranchTip: false
  },
  {
    hash: '758174d',
    committerDate: '2024-11-15T10:25:57+00:00',
    authorDate: '2024-10-15 10:25:57 +0100',
    message: 'feat(graph): encapsulated more graph styling into custom hook and added active dot radius value',
    parents: [
      'b081373'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '55c405d'
    ],
    isBranchTip: false
  },
  {
    hash: 'b081373',
    committerDate: '2024-11-15T10:04:16+00:00',
    authorDate: '2024-10-15 10:04:16 +0100',
    message: 'chore(state): hoisted graph data to react context and fixed render instability',
    parents: [
      'e50f872'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '758174d'
    ],
    isBranchTip: false
  },
  {
    hash: 'e50f872',
    committerDate: '2024-11-15T09:42:31+00:00',
    authorDate: '2024-10-15 09:42:31 +0100',
    message: 'chore(state): hoisted sleep page state management to react context',
    parents: [
      '5b5f0a9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b081373'
    ],
    isBranchTip: false
  },
  {
    hash: '5b5f0a9',
    committerDate: '2024-11-15T09:23:48+00:00',
    authorDate: '2024-10-15 09:23:48 +0100',
    message: 'feat(graph): graph config now render translucent and becomes opaque on hover',
    parents: [
      '9e6b6d9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e50f872'
    ],
    isBranchTip: false
  },
  {
    hash: '9e6b6d9',
    committerDate: '2024-11-14T19:45:07+00:00',
    authorDate: '2024-10-14 19:45:07 +0100',
    message: 'feat(graph): lines now start on the left viewport edge and y-ticks have a background',
    parents: [
      'e544bc3'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5b5f0a9'
    ],
    isBranchTip: false
  },
  {
    hash: 'e544bc3',
    committerDate: '2024-11-14T19:03:44+00:00',
    authorDate: '2024-10-14 19:03:44 +0100',
    message: 'feat(routing): added 404 not found page',
    parents: [
      'd683d57'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9e6b6d9'
    ],
    isBranchTip: false
  },
  {
    hash: '3cf1df4',
    committerDate: '2024-11-14T18:37:31+00:00',
    authorDate: '2024-10-14 18:37:31 +0100',
    message: 'Merge pull request #7 from TomPlum/develop',
    parents: [
      '67d24a6',
      'd683d57'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7125412'
    ],
    isBranchTip: false
  },
  {
    hash: 'd683d57',
    committerDate: '2024-11-14T18:37:03+00:00',
    authorDate: '2024-10-14 18:37:03 +0100',
    message: 'chore(build): added vite base path for gh-pages deployment',
    parents: [
      '3a9d56e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'e544bc3',
      '3cf1df4'
    ],
    isBranchTip: false
  },
  {
    hash: '67d24a6',
    committerDate: '2024-11-14T14:57:04+00:00',
    authorDate: '2024-10-14 14:57:04 +0100',
    message: 'Merge pull request #6 from TomPlum/develop',
    parents: [
      'bffed4c',
      '3a9d56e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3cf1df4'
    ],
    isBranchTip: false
  },
  {
    hash: '3a9d56e',
    committerDate: '2024-11-14T14:56:00+00:00',
    authorDate: '2024-10-14 14:56:00 +0100',
    message: 'chore(build): fixed build issues for release',
    parents: [
      '17b8e10'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd683d57',
      '67d24a6'
    ],
    isBranchTip: false
  },
  {
    hash: 'bffed4c',
    committerDate: '2024-11-14T14:47:46+00:00',
    authorDate: '2024-10-14 14:47:46 +0100',
    message: 'Merge pull request #5 from TomPlum/develop',
    parents: [
      'fd2f791',
      '17b8e10'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '67d24a6'
    ],
    isBranchTip: false
  },
  {
    hash: '17b8e10',
    committerDate: '2024-11-14T14:47:19+00:00',
    authorDate: '2024-10-14 14:47:19 +0100',
    message: 'chore(ci): renamed main workflow -> release',
    parents: [
      'fd2f791'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '3a9d56e',
      'bffed4c'
    ],
    isBranchTip: false
  },
  {
    hash: 'fd2f791',
    committerDate: '2024-11-14T14:45:08+00:00',
    authorDate: '2024-10-14 14:45:08 +0100',
    message: 'Merge pull request #4 from TomPlum/renovate/all-minor-patch',
    parents: [
      'b166be8',
      'a3aad32'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bffed4c',
      '17b8e10'
    ],
    isBranchTip: false
  },
  {
    hash: 'a3aad32',
    committerDate: '2024-11-14T14:44:02+00:00',
    authorDate: '2024-10-14 13:44:02 +0000',
    message: 'chore(deps): update all non-major dependencies',
    parents: [
      'b166be8'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      'fd2f791'
    ],
    isBranchTip: false
  },
  {
    hash: 'b166be8',
    committerDate: '2024-11-14T14:41:43+00:00',
    authorDate: '2024-10-14 14:41:43 +0100',
    message: 'Merge pull request #2 from TomPlum/develop',
    parents: [
      'd399e92',
      '6376640'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'fd2f791',
      'a3aad32'
    ],
    isBranchTip: false
  },
  {
    hash: '6376640',
    committerDate: '2024-11-14T14:41:24+00:00',
    authorDate: '2024-10-14 14:41:24 +0100',
    message: 'chore(config): updated renovate rules, schedule and assignee',
    parents: [
      '30d449b'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b166be8'
    ],
    isBranchTip: false
  },
  {
    hash: '30d449b',
    committerDate: '2024-11-14T14:39:59+00:00',
    authorDate: '2024-10-14 14:39:59 +0100',
    message: 'Merge pull request #1 from TomPlum/renovate/configure',
    parents: [
      'd399e92',
      '949b36d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6376640'
    ],
    isBranchTip: false
  },
  {
    hash: '949b36d',
    committerDate: '2024-11-14T14:37:36+00:00',
    authorDate: '2024-10-14 13:37:36 +0000',
    message: 'Add renovate.json',
    parents: [
      'd399e92'
    ],
    branch: 'release',
    author: {
      name: 'renovate[bot]',
      email: '29139614+renovate[bot]@users.noreply.github.com'
    },
    children: [
      '30d449b'
    ],
    isBranchTip: false
  },
  {
    hash: 'd399e92',
    committerDate: '2024-11-14T10:45:28+00:00',
    authorDate: '2024-10-14 10:45:28 +0100',
    message: 'chore(ci): added gh-pages package and added github actions main workflow',
    parents: [
      '96d0ac5'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b166be8',
      '30d449b',
      '949b36d'
    ],
    isBranchTip: false
  },
  {
    hash: '96d0ac5',
    committerDate: '2024-11-14T10:41:44+00:00',
    authorDate: '2024-10-14 10:41:44 +0100',
    message: 'feat(graph): extracted metric checkbox component and changed colours based on metric',
    parents: [
      '1e65c1d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd399e92'
    ],
    isBranchTip: false
  },
  {
    hash: '1e65c1d',
    committerDate: '2024-11-14T10:07:12+00:00',
    authorDate: '2024-10-14 10:07:12 +0100',
    message: 'feat(graph): added pie to to tooltip and extracted graph styles hook',
    parents: [
      '30dcafd'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '96d0ac5'
    ],
    isBranchTip: false
  },
  {
    hash: '30dcafd',
    committerDate: '2024-11-14T09:28:43+00:00',
    authorDate: '2024-10-14 09:28:43 +0100',
    message: 'chore(graph): minor improvements to graph formatting & styling',
    parents: [
      '72b1f86'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1e65c1d'
    ],
    isBranchTip: false
  },
  {
    hash: '72b1f86',
    committerDate: '2024-11-14T07:55:23+00:00',
    authorDate: '2024-10-14 07:55:23 +0100',
    message: 'chore(graph): extracted sleep data 2d hook',
    parents: [
      '2115a48'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '30dcafd'
    ],
    isBranchTip: false
  },
  {
    hash: '2115a48',
    committerDate: '2024-11-14T07:45:57+00:00',
    authorDate: '2024-10-14 07:45:57 +0100',
    message: 'feat(graph): increased axis tick stroke width',
    parents: [
      '0bf74b1'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '72b1f86'
    ],
    isBranchTip: false
  },
  {
    hash: '0bf74b1',
    committerDate: '2024-11-14T07:43:44+00:00',
    authorDate: '2024-10-14 07:43:44 +0100',
    message: 'feat(graph): added custom x-axis tick component',
    parents: [
      '5a6b882'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '2115a48'
    ],
    isBranchTip: false
  },
  {
    hash: '5a6b882',
    committerDate: '2024-11-13T16:27:42+00:00',
    authorDate: '2024-10-13 16:27:42 +0100',
    message: 'feat(graph): tweaked colours and now stroke width is dynamic based on dataset size',
    parents: [
      '9cfcece'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '0bf74b1'
    ],
    isBranchTip: false
  },
  {
    hash: '9cfcece',
    committerDate: '2024-11-13T16:19:46+00:00',
    authorDate: '2024-10-13 16:19:46 +0100',
    message: 'feat(routing): sleep route now adds default query params if not present',
    parents: [
      '603fbbc'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5a6b882'
    ],
    isBranchTip: false
  },
  {
    hash: '603fbbc',
    committerDate: '2024-11-13T15:24:07+00:00',
    authorDate: '2024-10-13 15:24:07 +0100',
    message: 'chore(test): fixed failing data test and added eslint stylistic plugin',
    parents: [
      'f892161'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9cfcece'
    ],
    isBranchTip: false
  },
  {
    hash: 'f892161',
    committerDate: '2024-11-13T12:31:54+00:00',
    authorDate: '2024-10-13 12:31:54 +0100',
    message: 'feat(graph): added custom tooltip and filtered out data with no breakdown',
    parents: [
      '9df8d6c'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '603fbbc'
    ],
    isBranchTip: false
  },
  {
    hash: '9df8d6c',
    committerDate: '2024-11-13T11:26:08+00:00',
    authorDate: '2024-10-13 11:26:08 +0100',
    message: 'chore(refactor): extracted custom y-axis tick component into its own file',
    parents: [
      'bb8d532'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'f892161'
    ],
    isBranchTip: false
  },
  {
    hash: 'bb8d532',
    committerDate: '2024-11-13T11:19:26+00:00',
    authorDate: '2024-10-13 11:19:26 +0100',
    message: 'chore(state): hoisted sleep data state management into a react context',
    parents: [
      '7955da7'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '9df8d6c'
    ],
    isBranchTip: false
  },
  {
    hash: '7955da7',
    committerDate: '2024-11-12T22:14:12+00:00',
    authorDate: '2024-10-12 22:14:12 +0100',
    message: 'feat(graph): formatting and styling improvements to 2d graph',
    parents: [
      '5109e9d'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'bb8d532'
    ],
    isBranchTip: false
  },
  {
    hash: '5109e9d',
    committerDate: '2024-11-12T22:01:25+00:00',
    authorDate: '2024-10-12 22:01:25 +0100',
    message: 'feat(routing): added custom query params hook and serialised date range in query params',
    parents: [
      'd160456'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7955da7'
    ],
    isBranchTip: false
  },
  {
    hash: 'd160456',
    committerDate: '2024-11-12T21:41:17+00:00',
    authorDate: '2024-10-12 21:41:17 +0100',
    message: 'feat(routing): added router, new base URL and serialised metric in query param',
    parents: [
      'a09ca48'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '5109e9d'
    ],
    isBranchTip: false
  },
  {
    hash: 'a09ca48',
    committerDate: '2024-11-12T19:54:44+00:00',
    authorDate: '2024-10-12 19:54:44 +0100',
    message: 'feat(graph): first pass at linear regression line',
    parents: [
      'c2ed208'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd160456'
    ],
    isBranchTip: false
  },
  {
    hash: 'c2ed208',
    committerDate: '2024-11-12T19:10:12+00:00',
    authorDate: '2024-10-12 19:10:12 +0100',
    message: 'feat(graph): added date range picker',
    parents: [
      '4522569'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'a09ca48'
    ],
    isBranchTip: false
  },
  {
    hash: '4522569',
    committerDate: '2024-11-12T17:05:28+00:00',
    authorDate: '2024-10-12 17:05:28 +0100',
    message: 'feat(graph): added colours to each sleep metric line',
    parents: [
      'eb371fa'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'c2ed208'
    ],
    isBranchTip: false
  },
  {
    hash: 'eb371fa',
    committerDate: '2024-11-12T16:52:25+00:00',
    authorDate: '2024-10-12 16:52:25 +0100',
    message: 'feat(graph): added metric configuration panel',
    parents: [
      '6530e27'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '4522569'
    ],
    isBranchTip: false
  },
  {
    hash: '6530e27',
    committerDate: '2024-11-12T10:55:38+00:00',
    authorDate: '2024-10-12 10:55:38 +0100',
    message: 'feat(graph): basic first pass at a 2D graph with recharts',
    parents: [
      'd94993e'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'eb371fa'
    ],
    isBranchTip: false
  },
  {
    hash: 'd94993e',
    committerDate: '2024-11-07T19:38:04+00:00',
    authorDate: '2024-10-07 19:38:04 +0100',
    message: 'feat(graph): added awake time to the 3d graph',
    parents: [
      '72de5c9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '6530e27'
    ],
    isBranchTip: false
  },
  {
    hash: '72de5c9',
    committerDate: '2024-11-06T17:11:49+00:00',
    authorDate: '2024-10-06 17:11:49 +0100',
    message: 'feat(graph): first pass of rendering a 2D sleep quality graph in 3D',
    parents: [
      '7e68687'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'd94993e'
    ],
    isBranchTip: false
  },
  {
    hash: '7e68687',
    committerDate: '2024-11-06T16:31:02+00:00',
    authorDate: '2024-10-06 16:31:02 +0100',
    message: 'feat(data): mapped pillow data into custom domain object and parsed raw values',
    parents: [
      'ab657c9'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '72de5c9'
    ],
    isBranchTip: false
  },
  {
    hash: 'ab657c9',
    committerDate: '2024-11-06T12:47:24+00:00',
    authorDate: '2024-10-06 12:47:24 +0100',
    message: 'feat(data): started parsing pillow CSV data',
    parents: [
      'b3e99e8'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '7e68687'
    ],
    isBranchTip: false
  },
  {
    hash: 'b3e99e8',
    committerDate: '2024-11-06T10:42:01+00:00',
    authorDate: '2024-10-06 10:42:01 +0100',
    message: 'chore(config): added react-force-graph and vitest dependencies + pillow data',
    parents: [
      '1e5c110'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'ab657c9'
    ],
    isBranchTip: false
  },
  {
    hash: '1e5c110',
    committerDate: '2024-11-06T10:34:20+00:00',
    authorDate: '2024-10-06 10:34:20 +0100',
    message: 'chore(config): added placeholder page title and favicon',
    parents: [
      '05d1859'
    ],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      'b3e99e8'
    ],
    isBranchTip: false
  },
  {
    hash: '05d1859',
    committerDate: '2024-11-06T09:36:22+00:00',
    authorDate: '2024-10-06 09:36:22 +0100',
    message: 'chore(setup): ran vite@latest with react-swc-ts template',
    parents: [],
    branch: 'release',
    author: {
      name: 'Thomas Plumpton',
      email: 'Thomas.Plumpton@hotmail.co.uk'
    },
    children: [
      '1e5c110'
    ],
    isBranchTip: false
  }
]